@@ -1,8 +1,6 @@
-/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
- *
- *  (C) 2001 by Argonne National Laboratory.
- *      See COPYRIGHT in top-level directory.
+ * Copyright (C) by Argonne National Laboratory
+ *     See COPYRIGHT in top-level directory
  */
 
 #include "mpiimpl.h"
@@ -15,7 +13,8 @@
 #elif defined(HAVE_PRAGMA_CRI_DUP)
 #pragma _CRI duplicate MPI_Attr_get as PMPI_Attr_get
 #elif defined(HAVE_WEAK_ATTRIBUTE)
-int MPI_Attr_get(MPI_Comm comm, int keyval, void *attribute_val, int *flag) __attribute__((weak,alias("PMPI_Attr_get")));
+int MPI_Attr_get(MPI_Comm comm, int keyval, void *attribute_val, int *flag)
+    __attribute__ ((weak, alias("PMPI_Attr_get")));
 #endif
 /* -- End Profiling Symbol Block */
 
@@ -27,24 +26,21 @@ int MPI_Attr_get(MPI_Comm comm, int keyval, void *attribute_val, int *flag) __at
 
 #endif
 
-#undef FUNCNAME
-#define FUNCNAME MPI_Attr_get
-
 /*@
 
 MPI_Attr_get - Retrieves attribute value by key
 
 Input Parameters:
-+ comm - communicator to which attribute is attached (handle) 
-- keyval - key value (integer) 
++ comm - communicator to which attribute is attached (handle)
+- keyval - key value (integer)
 
 Output Parameters:
 + attribute_val - attribute value, unless 'flag' = false
 - flag -  true if an attribute value was extracted;  false if no attribute is
-  associated with the key 
+  associated with the key
 
 Notes:
-    Attributes must be extracted from the same language as they were inserted  
+    Attributes must be extracted from the same language as they were inserted
     in with 'MPI_ATTR_PUT'.  The notes for C and Fortran below explain why.
 
 Notes for C:
@@ -62,7 +58,7 @@ Notes for C:
 .N Fortran
 
     The 'attribute_val' in Fortran is a pointer to a Fortran integer, not
-    a pointer to a 'void *'.  
+    a pointer to a 'void *'.
 
 .N Errors
 .N MPI_SUCCESS
@@ -73,76 +69,68 @@ Notes for C:
 @*/
 int MPI_Attr_get(MPI_Comm comm, int keyval, void *attribute_val, int *flag)
 {
-    static const char FCNAME[] = "MPI_Attr_get";
     int mpi_errno = MPI_SUCCESS;
-    MPID_Comm *comm_ptr = NULL;
-    MPID_MPI_STATE_DECL(MPID_STATE_MPI_ATTR_GET);
+    MPIR_Comm *comm_ptr = NULL;
+    MPIR_FUNC_TERSE_STATE_DECL(MPID_STATE_MPI_ATTR_GET);
 
     MPIR_ERRTEST_INITIALIZED_ORDIE();
-    
+
     MPID_THREAD_CS_ENTER(GLOBAL, MPIR_THREAD_GLOBAL_ALLFUNC_MUTEX);
-    MPID_MPI_FUNC_ENTER(MPID_STATE_MPI_ATTR_GET);
+    MPIR_FUNC_TERSE_ENTER(MPID_STATE_MPI_ATTR_GET);
 
     /* Validate parameters, especially handles needing to be converted */
-#   ifdef HAVE_ERROR_CHECKING
+#ifdef HAVE_ERROR_CHECKING
     {
         MPID_BEGIN_ERROR_CHECKS;
         {
-	    MPIR_ERRTEST_COMM(comm, mpi_errno);
-#           ifdef NEEDS_POINTER_ALIGNMENT_ADJUST
-            /* A common user error is to pass the address of a 4-byte
-	       int when the address of a pointer (or an address-sized int)
-	       should have been used.  We can test for this specific
-	       case.  Note that this code assumes sizeof(MPIU_Pint) is 
-	       a power of 2. */
-            MPIR_ERR_CHKANDJUMP((MPIU_Pint)attribute_val & (sizeof(MPIU_Pint)-1),
-                                mpi_errno,MPI_ERR_ARG,"**attrnotptr");
-#           endif
+            MPIR_ERRTEST_COMM(comm, mpi_errno);
         }
         MPID_END_ERROR_CHECKS;
     }
-#   endif
-    
+#endif
+
     /* Convert MPI object handles to object pointers */
-    MPID_Comm_get_ptr( comm, comm_ptr );
+    MPIR_Comm_get_ptr(comm, comm_ptr);
 
     /* Validate parameters and objects (post conversion) */
-#   ifdef HAVE_ERROR_CHECKING
+#ifdef HAVE_ERROR_CHECKING
     {
         MPID_BEGIN_ERROR_CHECKS;
         {
             /* Validate comm_ptr */
-            MPID_Comm_valid_ptr( comm_ptr, mpi_errno, TRUE );
-	    /* If comm_ptr is not valid, it will be reset to null */
-	    MPIR_ERRTEST_ARGNULL(attribute_val, "attribute_val", mpi_errno);
-	    MPIR_ERRTEST_ARGNULL(flag, "flag", mpi_errno);
+            MPIR_Comm_valid_ptr(comm_ptr, mpi_errno, TRUE);
+            /* If comm_ptr is not valid, it will be reset to null */
+            MPIR_ERRTEST_ARGNULL(attribute_val, "attribute_val", mpi_errno);
+            MPIR_ERRTEST_ARGNULL(flag, "flag", mpi_errno);
         }
         MPID_END_ERROR_CHECKS;
     }
-#   endif /* HAVE_ERROR_CHECKING */
+#endif /* HAVE_ERROR_CHECKING */
 
     /* ... body of routine ...  */
 
-    mpi_errno = MPIR_CommGetAttr( comm, keyval, attribute_val, flag, MPIR_ATTR_PTR);
-    if (mpi_errno != MPI_SUCCESS) goto fn_fail;
+    mpi_errno = MPII_Comm_get_attr(comm, keyval, attribute_val, flag, MPIR_ATTR_PTR);
+    if (mpi_errno != MPI_SUCCESS)
+        goto fn_fail;
 
     /* ... end of body of routine ... */
 
   fn_exit:
-    MPID_MPI_FUNC_EXIT(MPID_STATE_MPI_ATTR_GET);
+    MPIR_FUNC_TERSE_EXIT(MPID_STATE_MPI_ATTR_GET);
     MPID_THREAD_CS_EXIT(GLOBAL, MPIR_THREAD_GLOBAL_ALLFUNC_MUTEX);
     return mpi_errno;
 
   fn_fail:
     /* --BEGIN ERROR HANDLING-- */
-#   ifdef HAVE_ERROR_CHECKING
+#ifdef HAVE_ERROR_CHECKING
     {
-	mpi_errno = MPIR_Err_create_code(
-	    mpi_errno, MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, MPI_ERR_OTHER, "**mpi_attr_get",
-	    "**mpi_attr_get %C %d %p %p", comm, keyval, attribute_val, flag);
+        mpi_errno =
+            MPIR_Err_create_code(mpi_errno, MPIR_ERR_RECOVERABLE, __func__, __LINE__, MPI_ERR_OTHER,
+                                 "**mpi_attr_get", "**mpi_attr_get %C %d %p %p", comm, keyval,
+                                 attribute_val, flag);
     }
-#   endif
-    mpi_errno = MPIR_Err_return_comm( comm_ptr, FCNAME, mpi_errno );
+#endif
+    mpi_errno = MPIR_Err_return_comm(comm_ptr, __func__, mpi_errno);
     goto fn_exit;
     /* --END ERROR HANDLING-- */
 }
