@@ -204,13 +204,8 @@ int MPIR_Iscan(const void *sendbuf, void *recvbuf, int count,
         mpi_errno = MPIR_Iscan_impl(sendbuf, recvbuf, count, datatype, op, comm_ptr, request);
     }
 
-    /* Copy out data from host recv buffer to GPU buffer */
-    if (host_recvbuf) {
-        recvbuf = in_recvbuf;
-        MPIR_Localcopy(host_recvbuf, count, datatype, recvbuf, count, datatype);
-    }
-
-    MPIR_Coll_host_buffer_free(host_sendbuf, host_recvbuf);
+    MPIR_Coll_host_buffer_swap_back(host_sendbuf, host_recvbuf, in_recvbuf, count, datatype,
+                                    *request);
 
     return mpi_errno;
 }
