@@ -27,7 +27,7 @@ cvars:
     - name        : MPIR_CVAR_COLLECTIVE_FALLBACK
       category    : COLLECTIVE
       type        : enum
-      default     : error
+      default     : silent
       class       : none
       verbosity   : MPI_T_VERBOSITY_USER_BASIC
       scope       : MPI_T_SCOPE_ALL_EQ
@@ -218,7 +218,7 @@ void MPIR_Coll_host_buffer_alloc(const void *sendbuf, const void *recvbuf, MPI_A
     MPI_Aint extent = 0;
 
     if (sendbuf != MPI_IN_PLACE) {
-        MPL_gpu_query_pointer_attr(sendbuf, &attr);
+        MPIR_GPU_query_pointer_attr(sendbuf, &attr);
         if (attr.type == MPL_GPU_POINTER_DEV) {
             MPI_Aint true_extent;
             MPI_Aint true_lb;
@@ -233,7 +233,7 @@ void MPIR_Coll_host_buffer_alloc(const void *sendbuf, const void *recvbuf, MPI_A
         }
     }
 
-    MPL_gpu_query_pointer_attr(recvbuf, &attr);
+    MPIR_GPU_query_pointer_attr(recvbuf, &attr);
     if (attr.type == MPL_GPU_POINTER_DEV) {
         if (!extent) {
             MPI_Aint true_extent;
@@ -256,3 +256,27 @@ void MPIR_Coll_host_buffer_free(void *host_sendbuf, void *host_recvbuf)
     MPL_free(host_sendbuf);
     MPL_free(host_recvbuf);
 }
+
+void MPIR_Coll_host_buffer_swap_back(void *host_sendbuf, void *host_recvbuf, void *in_recvbuf,
+                                     MPI_Aint count, MPI_Datatype datatype, MPIR_Request * request)
+{
+    if (host_recvbuf == NULL) {
+        /* no copy at completion necessary, just return */
+        return;
+    }
+
+    if (request == NULL || MPIR_Request_is_complete(request)) {
+        /* operation is complete, copy the data and return */
+        MPIR_Localcopy(host_recvbuf, count, datatype, in_recvbuf, count, datatype);
+        MPIR_Coll_host_buffer_free(host_sendbuf, host_recvbuf);
+        return;
+    }
+
+    /* data will be copied later during request completion */
+    request->u.nbc.coll.host_sendbuf = host_sendbuf;
+    request->u.nbc.coll.host_recvbuf = host_recvbuf;
+    request->u.nbc.coll.user_recvbuf = in_recvbuf;
+    request->u.nbc.coll.count = count;
+    request->u.nbc.coll.datatype = datatype;
+    MPIR_Datatype_add_ref_if_not_builtin(datatype);
+}
