@@ -1,8 +1,6 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /*
- *
- *  (C) 2001 by Argonne National Laboratory.
- *      See COPYRIGHT in top-level directory.
+ * Copyright (C) by Argonne National Laboratory
+ *     See COPYRIGHT in top-level directory
  */
 
 #include "mpiimpl.h"
@@ -15,6 +13,9 @@
 #pragma _HP_SECONDARY_DEF PMPI_Add_error_code  MPI_Add_error_code
 #elif defined(HAVE_PRAGMA_CRI_DUP)
 #pragma _CRI duplicate MPI_Add_error_code as PMPI_Add_error_code
+#elif defined(HAVE_WEAK_ATTRIBUTE)
+int MPI_Add_error_code(int errorclass, int *errorcode)
+    __attribute__ ((weak, alias("PMPI_Add_error_code")));
 #endif
 /* -- End Profiling Symbol Block */
 
@@ -26,16 +27,13 @@
 
 #endif
 
-#undef FUNCNAME
-#define FUNCNAME MPI_Add_error_code
-
 /*@
-   MPI_Add_error_code - Add and MPI error code to an MPI error class
+   MPI_Add_error_code - Add an MPI error code to an MPI error class
 
-   Input Parameter:
+Input Parameters:
 .  errorclass - Error class to add an error code.
 
-   Output Parameter:
+Output Parameters:
 .  errorcode - New error code for this error class.
 
 .N ThreadSafe
@@ -48,53 +46,52 @@
 @*/
 int MPI_Add_error_code(int errorclass, int *errorcode)
 {
-    static const char FCNAME[] = "MPI_Add_error_code";
     int mpi_errno = MPI_SUCCESS;
     int new_code;
-    MPID_MPI_STATE_DECL(MPID_STATE_MPI_ADD_ERROR_CODE);
+    MPIR_FUNC_TERSE_STATE_DECL(MPID_STATE_MPI_ADD_ERROR_CODE);
 
     MPIR_ERRTEST_INITIALIZED_ORDIE();
-    
-    MPIU_THREAD_CS_ENTER(ALLFUNC,);
-    MPID_MPI_FUNC_ENTER(MPID_STATE_MPI_ADD_ERROR_CODE);
+
+    MPID_THREAD_CS_ENTER(GLOBAL, MPIR_THREAD_GLOBAL_ALLFUNC_MUTEX);
+    MPIR_FUNC_TERSE_ENTER(MPID_STATE_MPI_ADD_ERROR_CODE);
 
     /* Validate parameters, especially handles needing to be converted */
-#   ifdef HAVE_ERROR_CHECKING
+#ifdef HAVE_ERROR_CHECKING
     {
         MPID_BEGIN_ERROR_CHECKS;
         {
-	    /* FIXME: verify that errorclass is a dynamic class */
-	    MPIR_ERRTEST_ARGNULL(errorcode, "errorcode", mpi_errno);
+            /* FIXME: verify that errorclass is a dynamic class */
+            MPIR_ERRTEST_ARGNULL(errorcode, "errorcode", mpi_errno);
         }
         MPID_END_ERROR_CHECKS;
     }
-#   endif /* HAVE_ERROR_CHECKING */
-    
+#endif /* HAVE_ERROR_CHECKING */
+
     /* ... body of routine ...  */
-    
-    new_code = MPIR_Err_add_code( errorclass );
-    MPIU_ERR_CHKANDJUMP(new_code<0,mpi_errno,MPI_ERR_OTHER,"**noerrcodes");
+
+    new_code = MPIR_Err_add_code(errorclass);
+    MPIR_ERR_CHKANDJUMP(new_code < 0, mpi_errno, MPI_ERR_OTHER, "**noerrcodes");
 
     *errorcode = new_code;
-    
+
     /* ... end of body of routine ... */
 
   fn_exit:
-    MPID_MPI_FUNC_EXIT(MPID_STATE_MPI_ADD_ERROR_CODE);
-    MPIU_THREAD_CS_EXIT(ALLFUNC,);
+    MPIR_FUNC_TERSE_EXIT(MPID_STATE_MPI_ADD_ERROR_CODE);
+    MPID_THREAD_CS_EXIT(GLOBAL, MPIR_THREAD_GLOBAL_ALLFUNC_MUTEX);
     return mpi_errno;
 
   fn_fail:
     /* --BEGIN ERROR HANDLING-- */
-#   ifdef HAVE_ERROR_CHECKING
+#ifdef HAVE_ERROR_CHECKING
     {
-	mpi_errno = MPIR_Err_create_code(
-	    mpi_errno, MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, MPI_ERR_OTHER, "**mpi_add_error_code",
-	    "**mpi_add_error_code %d %p", errorclass, errorcode);
+        mpi_errno =
+            MPIR_Err_create_code(mpi_errno, MPIR_ERR_RECOVERABLE, __func__, __LINE__, MPI_ERR_OTHER,
+                                 "**mpi_add_error_code", "**mpi_add_error_code %d %p", errorclass,
+                                 errorcode);
     }
-#   endif
-    mpi_errno = MPIR_Err_return_comm( NULL, FCNAME, mpi_errno );
+#endif
+    mpi_errno = MPIR_Err_return_comm(NULL, __func__, mpi_errno);
     goto fn_exit;
     /* --END ERROR HANDLING-- */
 }
-
