@@ -1,8 +1,6 @@
-/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
- *
- *  (C) 2001 by Argonne National Laboratory.
- *      See COPYRIGHT in top-level directory.
+ * Copyright (C) by Argonne National Laboratory
+ *     See COPYRIGHT in top-level directory
  */
 
 #include "mpiimpl.h"
@@ -27,15 +25,12 @@ int MPI_Group_difference(MPI_Group group1, MPI_Group group2, MPI_Group * newgrou
 #undef MPI_Group_difference
 #define MPI_Group_difference PMPI_Group_difference
 
-#undef FUNCNAME
-#define FUNCNAME MPIR_Group_difference_impl
-#undef FCNAME
-#define FCNAME MPL_QUOTE(FUNCNAME)
 int MPIR_Group_difference_impl(MPIR_Group * group_ptr1, MPIR_Group * group_ptr2,
                                MPIR_Group ** new_group_ptr)
 {
     int mpi_errno = MPI_SUCCESS;
     int size1, i, k, g1_idx, g2_idx, l1_pid, l2_pid, nnew;
+    int *flags = NULL;
     MPIR_FUNC_TERSE_STATE_DECL(MPID_STATE_MPIR_GROUP_DIFFERENCE_IMPL);
 
     MPIR_FUNC_TERSE_ENTER(MPID_STATE_MPIR_GROUP_DIFFERENCE_IMPL);
@@ -45,8 +40,7 @@ int MPIR_Group_difference_impl(MPIR_Group * group_ptr1, MPIR_Group * group_ptr2,
     /* Insure that the lpid lists are setup */
     MPIR_Group_setup_lpid_pairs(group_ptr1, group_ptr2);
 
-    for (i = 0; i < size1; i++)
-        group_ptr1->lrank_to_lpid[i].flag = 0;
+    flags = MPL_calloc(size1, sizeof(int), MPL_MEM_OTHER);
 
     g1_idx = group_ptr1->idx_of_first_lpid;
     g2_idx = group_ptr2->idx_of_first_lpid;
@@ -61,7 +55,7 @@ int MPIR_Group_difference_impl(MPIR_Group * group_ptr1, MPIR_Group * group_ptr2,
             g2_idx = group_ptr2->lrank_to_lpid[g2_idx].next_lpid;
         } else {
             /* Equal */
-            group_ptr1->lrank_to_lpid[g1_idx].flag = 1;
+            flags[g1_idx] = 1;
             g1_idx = group_ptr1->lrank_to_lpid[g1_idx].next_lpid;
             g2_idx = group_ptr2->lrank_to_lpid[g2_idx].next_lpid;
             nnew--;
@@ -84,7 +78,7 @@ int MPIR_Group_difference_impl(MPIR_Group * group_ptr1, MPIR_Group * group_ptr2,
         (*new_group_ptr)->rank = MPI_UNDEFINED;
         k = 0;
         for (i = 0; i < size1; i++) {
-            if (!group_ptr1->lrank_to_lpid[i].flag) {
+            if (!flags[i]) {
                 (*new_group_ptr)->lrank_to_lpid[k].lpid = group_ptr1->lrank_to_lpid[i].lpid;
                 if (i == group_ptr1->rank)
                     (*new_group_ptr)->rank = k;
@@ -94,8 +88,8 @@ int MPIR_Group_difference_impl(MPIR_Group * group_ptr1, MPIR_Group * group_ptr2,
         /* TODO calculate is_local_dense_monotonic */
     }
 
-
   fn_exit:
+    MPL_free(flags);
     MPIR_FUNC_TERSE_EXIT(MPID_STATE_MPIR_GROUP_DIFFERENCE_IMPL);
     return mpi_errno;
   fn_fail:
@@ -105,10 +99,6 @@ int MPIR_Group_difference_impl(MPIR_Group * group_ptr1, MPIR_Group * group_ptr2,
 
 #endif
 
-#undef FUNCNAME
-#define FUNCNAME MPI_Group_difference
-#undef FCNAME
-#define FCNAME MPL_QUOTE(FUNCNAME)
 
 /*@
 
@@ -201,12 +191,12 @@ int MPI_Group_difference(MPI_Group group1, MPI_Group group2, MPI_Group * newgrou
 #ifdef HAVE_ERROR_CHECKING
     {
         mpi_errno =
-            MPIR_Err_create_code(mpi_errno, MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, MPI_ERR_OTHER,
+            MPIR_Err_create_code(mpi_errno, MPIR_ERR_RECOVERABLE, __func__, __LINE__, MPI_ERR_OTHER,
                                  "**mpi_group_difference", "**mpi_group_difference %G %G %p",
                                  group1, group2, newgroup);
     }
 #endif
-    mpi_errno = MPIR_Err_return_comm(NULL, FCNAME, mpi_errno);
+    mpi_errno = MPIR_Err_return_comm(NULL, __func__, mpi_errno);
     goto fn_exit;
     /* --END ERROR HANDLING-- */
 }
