@@ -1,11 +1,14 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
 /*
- *  (C) 2001 by Argonne National Laboratory.
- *      See COPYRIGHT in top-level directory.
+ * Copyright (C) by Argonne National Laboratory
+ *     See COPYRIGHT in top-level directory
  */
+
+#ifndef MPIPR_H_INCLUDED
+#define MPIPR_H_INCLUDED
+
 /* This file replaces all MPI function names with their PMPI equivalents.
-   PMPI versions are used by default so that the user can profile 
-   application code without interference from MPI functions used by 
+   PMPI versions are used by default so that the user can profile
+   application code without interference from MPI functions used by
    MPI-IO. */
 
 #ifndef USE_MPI_VERSIONS
@@ -251,8 +254,8 @@
 /* #define MPI_Type_create_darray PMPI_Type_create_darray */
 #undef MPI_Type_create_indexed_block
 #define MPI_Type_create_indexed_block PMPI_Type_create_indexed_block
-#undef MPIX_Type_create_hindexed_block
-#define MPIX_Type_create_hindexed_block PMPIX_Type_create_hindexed_block
+#undef MPI_Type_create_hindexed_block
+#define MPI_Type_create_hindexed_block PMPI_Type_create_hindexed_block
 /* #define MPI_Type_create_subarray PMPI_Type_create_subarray */
 #undef MPI_Type_extent
 #define MPI_Type_extent PMPI_Type_extent
@@ -274,6 +277,8 @@
 #define MPI_Type_lb PMPI_Type_lb
 #undef MPI_Type_size
 #define MPI_Type_size PMPI_Type_size
+#undef MPI_Type_size_x
+#define MPI_Type_size_x PMPI_Type_size_x
 #undef MPI_Type_struct
 #define MPI_Type_struct PMPI_Type_struct
 #undef MPI_Type_ub
@@ -295,7 +300,7 @@
 #undef MPI_Wtime
 #define MPI_Wtime PMPI_Wtime
 
-/* commented out because these could be macros themselves, as in MPICH 
+/* commented out because these could be macros themselves, as in MPICH
 #undef MPI_Type_c2f
 #define MPI_Type_c2f PMPI_Type_c2f
 #undef MPI_Type_f2c
@@ -328,8 +333,10 @@
 
 #undef MPI_Status_set_elements
 #define MPI_Status_set_elements PMPI_Status_set_elements
+#undef MPI_Status_set_elements_x
+#define MPI_Status_set_elements_x PMPI_Status_set_elements_x
 
-#ifndef HAVE_MPI_INFO_SRC  /* everywhere except in info source directory */
+#ifndef HAVE_MPI_INFO_SRC       /* everywhere except in info source directory */
 #undef MPI_Info_create
 #define MPI_Info_create PMPI_Info_create
 #undef MPI_Info_set
@@ -366,7 +373,7 @@
 #undef MPIX_Grequest_class_allocate
 #define MPIX_Grequest_class_allocate PMPIX_Grequest_class_allocate
 
-#ifdef MPIO_FORTRAN_SRC   /* only in MPI-IO Fortran source directory */
+#ifdef MPIO_FORTRAN_SRC /* only in MPI-IO Fortran source directory */
 #undef MPI_File_c2f
 #define MPI_File_c2f PMPI_File_c2f
 #undef MPI_File_f2c
@@ -383,3 +390,5 @@
 #define MPI_Type_create_keyval PMPI_Type_create_keyval
 
 #endif
+
+#endif /* MPIPR_H_INCLUDED */
