@@ -1,8 +1,6 @@
-/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
-/* 
- *
- *   Copyright (C) 1997 University of Chicago. 
- *   See COPYRIGHT notice in top-level directory.
+/*
+ * Copyright (C) by Argonne National Laboratory
+ *     See COPYRIGHT in top-level directory
  */
 
 #include "mpioimpl.h"
@@ -16,6 +14,9 @@
 #elif defined(HAVE_PRAGMA_CRI_DUP)
 #pragma _CRI duplicate MPI_File_read_ordered_end as PMPI_File_read_ordered_end
 /* end of weak pragmas */
+#elif defined(HAVE_WEAK_ATTRIBUTE)
+int MPI_File_read_ordered_end(MPI_File fh, void *buf, MPI_Status * status)
+    __attribute__ ((weak, alias("PMPI_File_read_ordered_end")));
 #endif
 
 /* Include mapping from MPI->PMPI */
@@ -35,39 +36,37 @@ Output Parameters:
 
 .N fortran
 @*/
-int MPI_File_read_ordered_end(MPI_File fh, void *buf, MPI_Status *status)
+int MPI_File_read_ordered_end(MPI_File fh, void *buf, MPI_Status * status)
 {
-    int error_code=MPI_SUCCESS;
+    int error_code = MPI_SUCCESS;
     ADIO_File adio_fh;
     static char myname[] = "MPI_FILE_READ_ORDERED_END";
 
-    MPIU_UNREFERENCED_ARG(buf);
+    MPL_UNREFERENCED_ARG(buf);
 
-    MPIU_THREAD_CS_ENTER(ALLFUNC,);
+    ROMIO_THREAD_CS_ENTER();
 
     adio_fh = MPIO_File_resolve(fh);
 
     /* --BEGIN ERROR HANDLING-- */
     MPIO_CHECK_FILE_HANDLE(adio_fh, myname, error_code);
 
-    if (!(adio_fh->split_coll_count))
-    {
-	error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
-					  myname, __LINE__, MPI_ERR_IO, 
-					  "**iosplitcollnone", 0);
-	error_code = MPIO_Err_return_file(adio_fh, error_code);
-	goto fn_exit;
+    if (!(adio_fh->split_coll_count)) {
+        error_code = MPIO_Err_create_code(MPI_SUCCESS, MPIR_ERR_RECOVERABLE,
+                                          myname, __LINE__, MPI_ERR_IO, "**iosplitcollnone", 0);
+        error_code = MPIO_Err_return_file(adio_fh, error_code);
+        goto fn_exit;
     }
     /* --END ERROR HANDLING-- */
 
 #ifdef HAVE_STATUS_SET_BYTES
     if (status != MPI_STATUS_IGNORE)
-       *status = adio_fh->split_status;
+        *status = adio_fh->split_status;
 #endif
     adio_fh->split_coll_count = 0;
 
-fn_exit:
-    MPIU_THREAD_CS_EXIT(ALLFUNC,);
+  fn_exit:
+    ROMIO_THREAD_CS_EXIT();
 
     return error_code;
 }
