@@ -1,7 +1,6 @@
-/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
- *  (C) 2001 by Argonne National Laboratory.
- *      See COPYRIGHT in top-level directory.
+ * Copyright (C) by Argonne National Laboratory
+ *     See COPYRIGHT in top-level directory
  */
 
 #include "mpidimpl.h"
@@ -13,39 +12,46 @@
  * datatype cases.
  */
 
-#undef FUNCNAME
-#define FUNCNAME MPIDI_CH3_SendNoncontig_iov
-#undef FCNAME
-#define FCNAME MPL_QUOTE(FUNCNAME)
 /* MPIDI_CH3_SendNoncontig_iov - Sends a message by loading an
    IOV and calling iSendv.  The caller must initialize
-   sreq->dev.segment as well as segment_first and segment_size. */
-int MPIDI_CH3_SendNoncontig_iov( MPIDI_VC_t *vc, MPID_Request *sreq,
-                                 void *header, MPIDI_msg_sz_t hdr_sz )
+   sreq->dev.segment as well as msg_offset and msgsize.
+   The optional hdr_iov and n_hdr_iov are used for variable-length extended
+   header, specify NULL and zero if unused. Note that we assume n_hdr_iov is
+   small and does not exceed MPL_IOV_LIMIT - 2 (one for header and one for
+   packed data) at most.  */
+int MPIDI_CH3_SendNoncontig_iov( MPIDI_VC_t *vc, MPIR_Request *sreq,
+                                 void *header, intptr_t hdr_sz,
+                                 struct iovec *hdr_iov, int n_hdr_iov)
 {
     int mpi_errno = MPI_SUCCESS;
-    int iov_n;
-    MPL_IOV iov[MPL_IOV_LIMIT];
-    MPIDI_STATE_DECL(MPID_STATE_MPIDI_CH3_SENDNONCONTIG_IOV);
+    int iov_n, iovcnt = 0;
+    struct iovec iov[MPL_IOV_LIMIT];
+    MPIR_FUNC_VERBOSE_STATE_DECL(MPID_STATE_MPIDI_CH3_SENDNONCONTIG_IOV);
 
-    MPIDI_FUNC_ENTER(MPID_STATE_MPIDI_CH3_SENDNONCONTIG_IOV);
+    MPIR_FUNC_VERBOSE_ENTER(MPID_STATE_MPIDI_CH3_SENDNONCONTIG_IOV);
 
-    iov[0].MPL_IOV_BUF = header;
-    iov[0].MPL_IOV_LEN = hdr_sz;
+    iov[iovcnt].iov_base = header;
+    iov[iovcnt].iov_len = hdr_sz;
+    iovcnt++;
 
     iov_n = MPL_IOV_LIMIT - 1;
 
-    if (sreq->dev.ext_hdr_sz > 0) {
-        /* When extended packet header exists, here we leave one IOV slot
-         * before loading data to IOVs, so that there will be enough
-         * IOVs for hdr/ext_hdr/data. */
-        iov_n--;
+    /* If extended header iov exists, merge into the iov array. */
+    if (n_hdr_iov > 0) {
+        int i;
+        MPIR_Assert(iov_n - n_hdr_iov > 0); /* secure at least 1 iov for data */
+        for (i = 0; i < n_hdr_iov; i++) {
+             iov[iovcnt].iov_base = hdr_iov[i].iov_base;
+             iov[iovcnt].iov_len = hdr_iov[i].iov_len;
+             iovcnt++;
+             iov_n--;
+        }
     }
 
-    mpi_errno = MPIDI_CH3U_Request_load_send_iov(sreq, &iov[1], &iov_n);
+    mpi_errno = MPIDI_CH3U_Request_load_send_iov(sreq, &iov[iovcnt], &iov_n);
     if (mpi_errno == MPI_SUCCESS)
     {
-	iov_n += 1;
+	iov_n += iovcnt;  /* add count of hdr iovs */
 	
 	/* Note this routine is invoked withing a CH3 critical section */
 	/* MPID_THREAD_CS_ENTER(POBJ, vc->pobj_mutex); */
@@ -54,7 +60,7 @@ int MPIDI_CH3_SendNoncontig_iov( MPIDI_VC_t *vc, MPID_Request *sreq,
 	/* --BEGIN ERROR HANDLING-- */
 	if (mpi_errno != MPI_SUCCESS)
 	{
-            MPID_Request_release(sreq);
+            MPIR_Request_free(sreq);
             MPIR_ERR_SETANDJUMP(mpi_errno, MPI_ERR_OTHER, "**ch3|eagermsg");
 	}
 	/* --END ERROR HANDLING-- */
@@ -65,14 +71,14 @@ int MPIDI_CH3_SendNoncontig_iov( MPIDI_VC_t *vc, MPID_Request *sreq,
     else
     {
 	/* --BEGIN ERROR HANDLING-- */
-        MPID_Request_release(sreq);
+        MPIR_Request_free(sreq);
         MPIR_ERR_SETANDJUMP(mpi_errno, MPI_ERR_OTHER, "**ch3|loadsendiov");
 	/* --END ERROR HANDLING-- */
     }
 
 
  fn_exit:
-    MPIDI_FUNC_EXIT(MPID_STATE_MPIDI_CH3_SENDNONCONTIG_IOV);
+    MPIR_FUNC_VERBOSE_EXIT(MPID_STATE_MPIDI_CH3_SENDNONCONTIG_IOV);
     return mpi_errno;
  fn_fail:
     goto fn_exit;
@@ -80,27 +86,28 @@ int MPIDI_CH3_SendNoncontig_iov( MPIDI_VC_t *vc, MPID_Request *sreq,
 
 /* This function will allocate a segment.  That segment must be freed when
    it is no longer needed */
-#undef FUNCNAME
-#define FUNCNAME MPIDI_EagerNoncontigSend
-#undef FCNAME
-#define FCNAME MPL_QUOTE(FUNCNAME)
 /* MPIDI_CH3_EagerNoncontigSend - Eagerly send noncontiguous data */
-int MPIDI_CH3_EagerNoncontigSend( MPID_Request **sreq_p, 
+int MPIDI_CH3_EagerNoncontigSend( MPIR_Request **sreq_p,
 				  MPIDI_CH3_Pkt_type_t reqtype, 
 				  const void * buf, MPI_Aint count,
-				  MPI_Datatype datatype, MPIDI_msg_sz_t data_sz,
+				  MPI_Datatype datatype,
 				  int rank, 
-				  int tag, MPID_Comm * comm, 
+				  int tag, MPIR_Comm * comm,
 				  int context_offset )
 {
     int mpi_errno = MPI_SUCCESS;
     MPIDI_VC_t * vc;
-    MPID_Request *sreq = *sreq_p;
+    MPIR_Request *sreq = *sreq_p;
     MPIDI_CH3_Pkt_t upkt;
     MPIDI_CH3_Pkt_eager_send_t * const eager_pkt = &upkt.eager_send;
-    
-    MPIU_DBG_MSG_FMT(CH3_OTHER,VERBOSE,(MPIU_DBG_FDEST,
-                     "sending non-contiguous eager message, data_sz=" MPIDI_MSG_SZ_FMT,
+    MPI_Aint data_sz;
+    MPIR_Datatype *dt_ptr;
+
+    MPIR_Datatype_get_ptr(datatype, dt_ptr);
+    data_sz = count * dt_ptr->size;
+
+    MPL_DBG_MSG_FMT(MPIDI_CH3_DBG_OTHER,VERBOSE,(MPL_DBG_FDEST,
+                     "sending non-contiguous eager message, data_sz=%" PRIdPTR,
 					data_sz));
     sreq->dev.OnDataAvail = 0;
     sreq->dev.OnFinal = 0;
@@ -118,21 +125,21 @@ int MPIDI_CH3_EagerNoncontigSend( MPID_Request **sreq_p,
     MPIDI_Pkt_set_seqnum(eager_pkt, seqnum);
     MPIDI_Request_set_seqnum(sreq, seqnum);
 
-    MPIU_DBG_MSGPKT(vc,tag,eager_pkt->match.parts.context_id,rank,data_sz,
+    MPL_DBG_MSGPKT(vc,tag,eager_pkt->match.parts.context_id,rank,data_sz,
                     "Eager");
-	    
-    sreq->dev.segment_ptr = MPID_Segment_alloc( );
-    MPIR_ERR_CHKANDJUMP1((sreq->dev.segment_ptr == NULL), mpi_errno, MPI_ERR_OTHER, "**nomem", "**nomem %s", "MPID_Segment_alloc");
 
-    MPID_Segment_init(buf, count, datatype, sreq->dev.segment_ptr, 0);
-    sreq->dev.segment_first = 0;
-    sreq->dev.segment_size = data_sz;
+    sreq->dev.user_buf = (void *) buf;
+    sreq->dev.user_count = count;
+    sreq->dev.datatype = datatype;
+    sreq->dev.msg_offset = 0;
+    sreq->dev.msgsize = data_sz;
 	    
     MPID_THREAD_CS_ENTER(POBJ, vc->pobj_mutex);
     mpi_errno = vc->sendNoncontig_fn(vc, sreq, eager_pkt, 
-                                     sizeof(MPIDI_CH3_Pkt_eager_send_t));
+                                     sizeof(MPIDI_CH3_Pkt_eager_send_t),
+                                     NULL, 0);
     MPID_THREAD_CS_EXIT(POBJ, vc->pobj_mutex);
-    if (mpi_errno) MPIR_ERR_POP(mpi_errno);
+    MPIR_ERR_CHECK(mpi_errno);
 
  fn_exit:
     return mpi_errno;
@@ -147,21 +154,17 @@ int MPIDI_CH3_EagerNoncontigSend( MPID_Request **sreq_p,
    Make sure that buf is at the beginning of the data to send; 
    adjust by adding dt_true_lb if necessary 
 */
-#undef FUNCNAME
-#define FUNCNAME MPIDI_EagerContigSend
-#undef FCNAME
-#define FCNAME MPL_QUOTE(FUNCNAME)
-int MPIDI_CH3_EagerContigSend( MPID_Request **sreq_p, 
+int MPIDI_CH3_EagerContigSend( MPIR_Request **sreq_p,
 			       MPIDI_CH3_Pkt_type_t reqtype, 
-			       const void * buf, MPIDI_msg_sz_t data_sz, int rank, 
-			       int tag, MPID_Comm * comm, int context_offset )
+			       const void * buf, intptr_t data_sz, int rank,
+			       int tag, MPIR_Comm * comm, int context_offset )
 {
     int mpi_errno = MPI_SUCCESS;
     MPIDI_VC_t * vc;
     MPIDI_CH3_Pkt_t upkt;
     MPIDI_CH3_Pkt_eager_send_t * const eager_pkt = &upkt.eager_send;
-    MPID_Request *sreq = *sreq_p;
-    MPL_IOV iov[2];
+    MPIR_Request *sreq = *sreq_p;
+    struct iovec iov[2];
     
     MPIDI_Pkt_init(eager_pkt, reqtype);
     eager_pkt->match.parts.rank	= comm->rank;
@@ -170,21 +173,21 @@ int MPIDI_CH3_EagerContigSend( MPID_Request **sreq_p,
     eager_pkt->sender_req_id	= MPI_REQUEST_NULL;
     eager_pkt->data_sz		= data_sz;
     
-    iov[0].MPL_IOV_BUF = (MPL_IOV_BUF_CAST)eager_pkt;
-    iov[0].MPL_IOV_LEN = sizeof(*eager_pkt);
+    iov[0].iov_base = (void *)eager_pkt;
+    iov[0].iov_len = sizeof(*eager_pkt);
     
-    MPIU_DBG_MSG_FMT(CH3_OTHER,VERBOSE,(MPIU_DBG_FDEST,
-	       "sending contiguous eager message, data_sz=" MPIDI_MSG_SZ_FMT,
+    MPL_DBG_MSG_FMT(MPIDI_CH3_DBG_OTHER,VERBOSE,(MPL_DBG_FDEST,
+	       "sending contiguous eager message, data_sz=%" PRIdPTR,
 					data_sz));
 	    
-    iov[1].MPL_IOV_BUF = (MPL_IOV_BUF_CAST) buf;
-    iov[1].MPL_IOV_LEN = data_sz;
+    iov[1].iov_base = (void *) buf;
+    iov[1].iov_len = data_sz;
     
     MPIDI_Comm_get_vc_set_active(comm, rank, &vc);
     MPIDI_VC_FAI_send_seqnum(vc, seqnum);
     MPIDI_Pkt_set_seqnum(eager_pkt, seqnum);
     
-    MPIU_DBG_MSGPKT(vc,tag,eager_pkt->match.parts.context_id,rank,data_sz,"EagerContig");
+    MPL_DBG_MSGPKT(vc,tag,eager_pkt->match.parts.context_id,rank,data_sz,"EagerContig");
     MPID_THREAD_CS_ENTER(POBJ, vc->pobj_mutex);
     mpi_errno = MPIDI_CH3_iStartMsgv(vc, iov, 2, sreq_p);
     MPID_THREAD_CS_EXIT(POBJ, vc->pobj_mutex);
@@ -213,14 +216,10 @@ int MPIDI_CH3_EagerContigSend( MPID_Request **sreq_p,
    We may need a nonblocking (cancellable) version of this, which will 
    have a smaller payload.
 */
-#undef FUNCNAME
-#define FUNCNAME MPIDI_EagerContigShortSend
-#undef FCNAME
-#define FCNAME MPL_QUOTE(FUNCNAME)
-int MPIDI_CH3_EagerContigShortSend( MPID_Request **sreq_p, 
-				    MPIDI_CH3_Pkt_type_t reqtype, 
-				    const void * buf, MPIDI_msg_sz_t data_sz, int rank, 
-				    int tag, MPID_Comm * comm, 
+int MPIDI_CH3_EagerContigShortSend( MPIR_Request **sreq_p,
+				    MPIDI_CH3_Pkt_type_t reqtype,
+				    const void * buf, intptr_t data_sz, int rank,
+				    int tag, MPIR_Comm * comm,
 				    int context_offset )
 {
     int mpi_errno = MPI_SUCCESS;
@@ -228,7 +227,7 @@ int MPIDI_CH3_EagerContigShortSend( MPID_Request **sreq_p,
     MPIDI_CH3_Pkt_t upkt;
     MPIDI_CH3_Pkt_eagershort_send_t * const eagershort_pkt = 
 	&upkt.eagershort_send;
-    MPID_Request *sreq = *sreq_p;
+    MPIR_Request *sreq = *sreq_p;
     
     /*    printf( "Sending short eager\n"); fflush(stdout); */
     MPIDI_Pkt_init(eagershort_pkt, reqtype);
@@ -237,8 +236,8 @@ int MPIDI_CH3_EagerContigShortSend( MPID_Request **sreq_p,
     eagershort_pkt->match.parts.context_id = comm->context_id + context_offset;
     eagershort_pkt->data_sz	     = data_sz;
     
-    MPIU_DBG_MSG_FMT(CH3_OTHER,VERBOSE,(MPIU_DBG_FDEST,
-       "sending contiguous short eager message, data_sz=" MPIDI_MSG_SZ_FMT,
+    MPL_DBG_MSG_FMT(MPIDI_CH3_DBG_OTHER,VERBOSE,(MPL_DBG_FDEST,
+       "sending contiguous short eager message, data_sz=%" PRIdPTR,
 					data_sz));
 	    
     MPIDI_Comm_get_vc_set_active(comm, rank, &vc);
@@ -258,7 +257,7 @@ int MPIDI_CH3_EagerContigShortSend( MPID_Request **sreq_p,
 	}
     }
 
-    MPIU_DBG_MSGPKT(vc,tag,eagershort_pkt->match.parts.context_id,rank,data_sz,
+    MPL_DBG_MSGPKT(vc,tag,eagershort_pkt->match.parts.context_id,rank,data_sz,
 		    "EagerShort");
     MPID_THREAD_CS_ENTER(POBJ, vc->pobj_mutex);
     mpi_errno = MPIDI_CH3_iStartMsg(vc, eagershort_pkt, sizeof(*eagershort_pkt), sreq_p);
@@ -284,28 +283,24 @@ int MPIDI_CH3_EagerContigShortSend( MPID_Request **sreq_p,
 
 /* This is the matching handler for the EagerShort message defined above */
 
-#undef FUNCNAME
-#define FUNCNAME MPIDI_CH3_PktHandler_EagerShortSend
-#undef FCNAME
-#define FCNAME MPL_QUOTE(FUNCNAME)
-int MPIDI_CH3_PktHandler_EagerShortSend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt, 
-					 MPIDI_msg_sz_t *buflen, MPID_Request **rreqp )
+int MPIDI_CH3_PktHandler_EagerShortSend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt, void *data ATTRIBUTE((unused)),
+					 intptr_t *buflen, MPIR_Request **rreqp )
 {
     MPIDI_CH3_Pkt_eagershort_send_t * eagershort_pkt = &pkt->eagershort_send;
-    MPID_Request * rreq;
+    MPIR_Request * rreq;
     int found;
     int mpi_errno = MPI_SUCCESS;
 
     MPID_THREAD_CS_ENTER(POBJ, MPIR_THREAD_POBJ_MSGQ_MUTEX);
 
     /* printf( "Receiving short eager!\n" ); fflush(stdout); */
-    MPIU_DBG_MSG_FMT(CH3_OTHER,VERBOSE,(MPIU_DBG_FDEST,
+    MPL_DBG_MSG_FMT(MPIDI_CH3_DBG_OTHER,VERBOSE,(MPL_DBG_FDEST,
 	"received eagershort send pkt, rank=%d, tag=%d, context=%d",
 	eagershort_pkt->match.parts.rank, 
 	eagershort_pkt->match.parts.tag, 
 	eagershort_pkt->match.parts.context_id));
 	    
-    MPIU_DBG_MSGPKT(vc,eagershort_pkt->match.parts.tag,
+    MPL_DBG_MSGPKT(vc,eagershort_pkt->match.parts.tag,
 		    eagershort_pkt->match.parts.context_id,
 		    eagershort_pkt->match.parts.rank,eagershort_pkt->data_sz,
 		    "ReceivedEagerShort");
@@ -315,7 +310,7 @@ int MPIDI_CH3_PktHandler_EagerShortSend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt,
     /* If the completion counter is 0, that means that the communicator to
      * which this message is being sent has been revoked and we shouldn't
      * bother finishing this. */
-    if (!found && MPID_cc_get(rreq->cc) == 0) {
+    if (!found && MPIR_cc_get(rreq->cc) == 0) {
         *rreqp = NULL;
         goto fn_fail;
     }
@@ -332,7 +327,7 @@ int MPIDI_CH3_PktHandler_EagerShortSend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt,
        The packet handler returns null for a request that requires
        no further communication */
     *rreqp = NULL;
-    *buflen = sizeof(MPIDI_CH3_Pkt_t);
+    *buflen = 0;
 
     /* Extract the data from the packet */
     /* Note that if the data size if zero, we're already done */
@@ -340,9 +335,9 @@ int MPIDI_CH3_PktHandler_EagerShortSend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt,
 	if (found) {
 	    int            dt_contig;
 	    MPI_Aint       dt_true_lb;
-	    MPIDI_msg_sz_t userbuf_sz;
-	    MPID_Datatype *dt_ptr;
-	    MPIDI_msg_sz_t data_sz;
+	    intptr_t userbuf_sz;
+	    MPIR_Datatype *dt_ptr;
+	    intptr_t data_sz;
 
 	    /* Make sure that we handle the general (non-contiguous)
 	       datatypes correctly while optimizing for the 
@@ -354,13 +349,13 @@ int MPIDI_CH3_PktHandler_EagerShortSend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt,
 		data_sz = rreq->dev.recv_data_sz;
 	    }
 	    else {
-		MPIU_DBG_MSG_FMT(CH3_OTHER,VERBOSE,(MPIU_DBG_FDEST,
-		    "receive buffer too small; message truncated, msg_sz=" 
-					  MPIDI_MSG_SZ_FMT ", userbuf_sz="
-				          MPIDI_MSG_SZ_FMT,
+		MPL_DBG_MSG_FMT(MPIDI_CH3_DBG_OTHER,VERBOSE,(MPL_DBG_FDEST,
+		    "receive buffer too small; message truncated, msg_sz=%"
+					  PRIdPTR ", userbuf_sz=%"
+				          PRIdPTR,
 				 rreq->dev.recv_data_sz, userbuf_sz));
 		rreq->status.MPI_ERROR = MPIR_Err_create_code(MPI_SUCCESS, 
-                     MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, MPI_ERR_TRUNCATE,
+                     MPIR_ERR_RECOVERABLE, __func__, __LINE__, MPI_ERR_TRUNCATE,
 		     "**truncate", "**truncate %d %d %d %d", 
 		     rreq->status.MPI_SOURCE, rreq->status.MPI_TAG, 
 		     rreq->dev.recv_data_sz, userbuf_sz );
@@ -396,29 +391,21 @@ int MPIDI_CH3_PktHandler_EagerShortSend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt,
 		   to fix this, but it will require a sweep of the code */
 	    }
 	    else {
-		MPIDI_msg_sz_t recv_data_sz;
-		MPI_Aint last;
-		/* user buffer is not contiguous.  Use the segment
-		   code to unpack it, handling various errors and 
-		   exceptional cases */
-		/* FIXME: The MPICH tests do not exercise this branch */
-		/* printf( "Surprise!\n" ); fflush(stdout);*/
-		rreq->dev.segment_ptr = MPID_Segment_alloc( );
-                MPIR_ERR_CHKANDJUMP1((rreq->dev.segment_ptr == NULL), mpi_errno, MPI_ERR_OTHER, "**nomem", "**nomem %s", "MPID_Segment_alloc");
-
-		MPID_Segment_init(rreq->dev.user_buf, rreq->dev.user_count, 
-				  rreq->dev.datatype, rreq->dev.segment_ptr, 0);
-
+		intptr_t recv_data_sz;
+		/* user buffer is not contiguous.  Unpack it, handling
+		   various errors and exceptional cases */
 		recv_data_sz = rreq->dev.recv_data_sz;
-		last    = recv_data_sz;
-		MPID_Segment_unpack( rreq->dev.segment_ptr, 0, 
-				     &last, eagershort_pkt->data );
-		if (last != recv_data_sz) {
+
+		MPI_Aint actual_unpack_bytes;
+		MPIR_Typerep_unpack(eagershort_pkt->data, recv_data_sz, rreq->dev.user_buf,
+				 rreq->dev.user_count, rreq->dev.datatype, 0, &actual_unpack_bytes);
+
+		if (actual_unpack_bytes != recv_data_sz) {
 		    /* --BEGIN ERROR HANDLING-- */
 		    /* There are two cases:  a datatype mismatch (could
 		       not consume all data) or a too-short buffer. We
 		       need to distinguish between these two types. */
-		    MPIR_STATUS_SET_COUNT(rreq->status, last);
+		    MPIR_STATUS_SET_COUNT(rreq->status, actual_unpack_bytes);
 		    if (rreq->dev.recv_data_sz <= userbuf_sz) {
 			MPIR_ERR_SETSIMPLE(rreq->status.MPI_ERROR,MPI_ERR_TYPE,
 					   "**dtypemismatch");
@@ -436,7 +423,7 @@ int MPIDI_CH3_PktHandler_EagerShortSend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt,
              * cool in this case?  No upper layer has a pointer to rreq yet
              * (it's unexpected and freshly allocated) 
              */
-	    MPIDI_msg_sz_t recv_data_sz;
+	    intptr_t recv_data_sz;
 	    /* This is easy; copy the data into a temporary buffer.
 	       To begin with, we use the same temporary location as
 	       is used in receiving eager unexpected data.
@@ -450,7 +437,7 @@ int MPIDI_CH3_PktHandler_EagerShortSend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt,
 	    /* printf( "Allocating into tmp\n" ); fflush(stdout); */
 	    recv_data_sz = rreq->dev.recv_data_sz;
         MPIR_T_PVAR_LEVEL_INC(RECVQ, unexpected_recvq_buffer_size, recv_data_sz);
-	    rreq->dev.tmpbuf = MPIU_Malloc(recv_data_sz);
+	    rreq->dev.tmpbuf = MPL_malloc(recv_data_sz, MPL_MEM_BUFFER);
 	    if (!rreq->dev.tmpbuf) {
 		MPIR_ERR_SETANDJUMP(mpi_errno,MPI_ERR_OTHER,"**nomem");
 	    }
@@ -500,9 +487,7 @@ int MPIDI_CH3_PktHandler_EagerShortSend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt,
      * also kicks the progress engine, which was previously done here via
      * MPIDI_CH3_Progress_signal_completion(). */
     mpi_errno = MPID_Request_complete(rreq);
-    if (mpi_errno != MPI_SUCCESS) {
-        MPIR_ERR_POP(mpi_errno);
-    }
+    MPIR_ERR_CHECK(mpi_errno);
 
  fn_fail:
     /* MT note: it may be possible to narrow this CS after careful
@@ -521,24 +506,20 @@ int MPIDI_CH3_PktHandler_EagerShortSend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt,
    Make sure that buf is at the beginning of the data to send; 
    adjust by adding dt_true_lb if necessary 
 */
-#undef FUNCNAME
-#define FUNCNAME MPIDI_EagerContigIsend
-#undef FCNAME
-#define FCNAME MPL_QUOTE(FUNCNAME)
-int MPIDI_CH3_EagerContigIsend( MPID_Request **sreq_p, 
+int MPIDI_CH3_EagerContigIsend( MPIR_Request **sreq_p,
 				MPIDI_CH3_Pkt_type_t reqtype, 
-				const void * buf, MPIDI_msg_sz_t data_sz, int rank, 
-				int tag, MPID_Comm * comm, int context_offset )
+				const void * buf, intptr_t data_sz, int rank,
+				int tag, MPIR_Comm * comm, int context_offset )
 {
     int mpi_errno = MPI_SUCCESS;
     MPIDI_VC_t * vc;
     MPIDI_CH3_Pkt_t upkt;
     MPIDI_CH3_Pkt_eager_send_t * const eager_pkt = &upkt.eager_send;
-    MPID_Request *sreq = *sreq_p;
-    MPL_IOV iov[MPL_IOV_LIMIT];
+    MPIR_Request *sreq = *sreq_p;
+    struct iovec iov[MPL_IOV_LIMIT];
 
-    MPIU_DBG_MSG_FMT(CH3_OTHER,VERBOSE,(MPIU_DBG_FDEST,
-	       "sending contiguous eager message, data_sz=" MPIDI_MSG_SZ_FMT,
+    MPL_DBG_MSG_FMT(MPIDI_CH3_DBG_OTHER,VERBOSE,(MPL_DBG_FDEST,
+	       "sending contiguous eager message, data_sz=%" PRIdPTR,
 					data_sz));
 	    
     sreq->dev.OnDataAvail = 0;
@@ -550,25 +531,25 @@ int MPIDI_CH3_EagerContigIsend( MPID_Request **sreq_p,
     eager_pkt->sender_req_id	= sreq->handle;
     eager_pkt->data_sz		= data_sz;
     
-    iov[0].MPL_IOV_BUF = (MPL_IOV_BUF_CAST)eager_pkt;
-    iov[0].MPL_IOV_LEN = sizeof(*eager_pkt);
+    iov[0].iov_base = (void *)eager_pkt;
+    iov[0].iov_len = sizeof(*eager_pkt);
     
-    iov[1].MPL_IOV_BUF = (MPL_IOV_BUF_CAST) buf;
-    iov[1].MPL_IOV_LEN = data_sz;
+    iov[1].iov_base = (void *) buf;
+    iov[1].iov_len = data_sz;
     
     MPIDI_Comm_get_vc_set_active(comm, rank, &vc);
     MPIDI_VC_FAI_send_seqnum(vc, seqnum);
     MPIDI_Pkt_set_seqnum(eager_pkt, seqnum);
     MPIDI_Request_set_seqnum(sreq, seqnum);
     
-    MPIU_DBG_MSGPKT(vc,tag,eager_pkt->match.parts.context_id,rank,data_sz,"EagerIsend");
+    MPL_DBG_MSGPKT(vc,tag,eager_pkt->match.parts.context_id,rank,data_sz,"EagerIsend");
     MPID_THREAD_CS_ENTER(POBJ, vc->pobj_mutex);
     mpi_errno = MPIDI_CH3_iSendv(vc, sreq, iov, 2);
     MPID_THREAD_CS_EXIT(POBJ, vc->pobj_mutex);
     /* --BEGIN ERROR HANDLING-- */
     if (mpi_errno != MPI_SUCCESS)
     {
-        MPID_Request_release(sreq);
+        MPIR_Request_free(sreq);
 	*sreq_p = NULL;
         MPIR_ERR_SETANDJUMP(mpi_errno, MPI_ERR_OTHER, "**ch3|eagermsg");
     }
@@ -600,28 +581,23 @@ int MPIDI_CH3_EagerContigIsend( MPID_Request **sreq_p,
 /* FIXME: This is not optimized for short messages, which 
    should have the data in the same packet when the data is
    particularly short (e.g., one 8 byte long word) */
-#undef FUNCNAME
-#define FUNCNAME MPIDI_CH3_PktHandler_EagerSend
-#undef FCNAME
-#define FCNAME MPL_QUOTE(FUNCNAME)
-int MPIDI_CH3_PktHandler_EagerSend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt, 
-				    MPIDI_msg_sz_t *buflen, MPID_Request **rreqp )
+int MPIDI_CH3_PktHandler_EagerSend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt, void *data,
+				    intptr_t *buflen, MPIR_Request **rreqp )
 {
     MPIDI_CH3_Pkt_eager_send_t * eager_pkt = &pkt->eager_send;
-    MPID_Request * rreq;
+    MPIR_Request * rreq;
     int found;
     int complete;
-    char *data_buf;
-    MPIDI_msg_sz_t data_len;
+    intptr_t data_len;
     int mpi_errno = MPI_SUCCESS;
 
     MPID_THREAD_CS_ENTER(POBJ, MPIR_THREAD_POBJ_MSGQ_MUTEX);
 
-    MPIU_DBG_MSG_FMT(CH3_OTHER,VERBOSE,(MPIU_DBG_FDEST,
+    MPL_DBG_MSG_FMT(MPIDI_CH3_DBG_OTHER,VERBOSE,(MPL_DBG_FDEST,
 	"received eager send pkt, sreq=0x%08x, rank=%d, tag=%d, context=%d",
 	eager_pkt->sender_req_id, eager_pkt->match.parts.rank, 
 	eager_pkt->match.parts.tag, eager_pkt->match.parts.context_id));
-    MPIU_DBG_MSGPKT(vc,eager_pkt->match.parts.tag,
+    MPL_DBG_MSGPKT(vc,eager_pkt->match.parts.tag,
 		    eager_pkt->match.parts.context_id,
 		    eager_pkt->match.parts.rank,eager_pkt->data_sz,
 		    "ReceivedEager");
@@ -632,33 +608,30 @@ int MPIDI_CH3_PktHandler_EagerSend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt,
     /* If the completion counter is 0, that means that the communicator to
      * which this message is being sent has been revoked and we shouldn't
      * bother finishing this. */
-    if (!found && MPID_cc_get(rreq->cc) == 0) {
+    if (!found && MPIR_cc_get(rreq->cc) == 0) {
         *rreqp = NULL;
         goto fn_fail;
     }
     
     set_request_info(rreq, eager_pkt, MPIDI_REQUEST_EAGER_MSG);
     
-    data_len = ((*buflen - sizeof(MPIDI_CH3_Pkt_t) >= rreq->dev.recv_data_sz)
-                ? rreq->dev.recv_data_sz : *buflen - sizeof(MPIDI_CH3_Pkt_t));
-    data_buf = (char *)pkt + sizeof(MPIDI_CH3_Pkt_t);
+    data_len = ((*buflen >= rreq->dev.recv_data_sz)
+                ? rreq->dev.recv_data_sz : *buflen);
     
     if (rreq->dev.recv_data_sz == 0) {
         /* return the number of bytes processed in this function */
-        *buflen = sizeof(MPIDI_CH3_Pkt_t);
+        *buflen = 0;
         mpi_errno = MPID_Request_complete(rreq);
-        if (mpi_errno != MPI_SUCCESS) {
-            MPIR_ERR_POP(mpi_errno);
-        }
+        MPIR_ERR_CHECK(mpi_errno);
 	*rreqp = NULL;
     }
     else {
 	if (found) {
-	    mpi_errno = MPIDI_CH3U_Receive_data_found( rreq, data_buf,
+	    mpi_errno = MPIDI_CH3U_Receive_data_found( rreq, data,
                                                        &data_len, &complete );
 	}
 	else {
-	    mpi_errno = MPIDI_CH3U_Receive_data_unexpected( rreq, data_buf,
+	    mpi_errno = MPIDI_CH3U_Receive_data_unexpected( rreq, data,
                                                             &data_len, &complete );
 	}
 
@@ -668,14 +641,12 @@ int MPIDI_CH3_PktHandler_EagerSend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt,
 	}
 
         /* return the number of bytes processed in this function */
-        *buflen = sizeof(MPIDI_CH3_Pkt_t) + data_len;
+        *buflen = data_len;
 
         if (complete) 
         {
             mpi_errno = MPID_Request_complete(rreq);
-            if (mpi_errno != MPI_SUCCESS) {
-                MPIR_ERR_POP(mpi_errno);
-            }
+            MPIR_ERR_CHECK(mpi_errno);
             *rreqp = NULL;
         }
         else
@@ -690,28 +661,23 @@ int MPIDI_CH3_PktHandler_EagerSend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt,
 }
 
 
-#undef FUNCNAME
-#define FUNCNAME MPIDI_CH3_PktHandler_ReadySend
-#undef FCNAME
-#define FCNAME MPL_QUOTE(FUNCNAME)
-int MPIDI_CH3_PktHandler_ReadySend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt,
-				    MPIDI_msg_sz_t *buflen, MPID_Request **rreqp )
+int MPIDI_CH3_PktHandler_ReadySend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt, void *data,
+				    intptr_t *buflen, MPIR_Request **rreqp )
 {
     MPIDI_CH3_Pkt_ready_send_t * ready_pkt = &pkt->ready_send;
-    MPID_Request * rreq;
+    MPIR_Request * rreq;
     int found;
     int complete;
-    char *data_buf;
-    MPIDI_msg_sz_t data_len;
+    intptr_t data_len;
     int mpi_errno = MPI_SUCCESS;
     
-    MPIU_DBG_MSG_FMT(CH3_OTHER,VERBOSE,(MPIU_DBG_FDEST,
+    MPL_DBG_MSG_FMT(MPIDI_CH3_DBG_OTHER,VERBOSE,(MPL_DBG_FDEST,
 	"received ready send pkt, sreq=0x%08x, rank=%d, tag=%d, context=%d",
 			ready_pkt->sender_req_id, 
 			ready_pkt->match.parts.rank, 
                         ready_pkt->match.parts.tag, 
 			ready_pkt->match.parts.context_id));
-    MPIU_DBG_MSGPKT(vc,ready_pkt->match.parts.tag,
+    MPL_DBG_MSGPKT(vc,ready_pkt->match.parts.tag,
 		    ready_pkt->match.parts.context_id,
 		    ready_pkt->match.parts.rank,ready_pkt->data_sz,
 		    "ReceivedReady");
@@ -722,29 +688,26 @@ int MPIDI_CH3_PktHandler_ReadySend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt,
     /* If the completion counter is 0, that means that the communicator to
      * which this message is being sent has been revoked and we shouldn't
      * bother finishing this. */
-    if (!found && MPID_cc_get(rreq->cc) == 0) {
+    if (!found && MPIR_cc_get(rreq->cc) == 0) {
         *rreqp = NULL;
         goto fn_fail;
     }
     
     set_request_info(rreq, ready_pkt, MPIDI_REQUEST_EAGER_MSG);
     
-    data_len = ((*buflen - sizeof(MPIDI_CH3_Pkt_t) >= rreq->dev.recv_data_sz)
-                ? rreq->dev.recv_data_sz : *buflen - sizeof(MPIDI_CH3_Pkt_t));
-    data_buf = (char *)pkt + sizeof(MPIDI_CH3_Pkt_t);
+    data_len = ((*buflen >= rreq->dev.recv_data_sz)
+                ? rreq->dev.recv_data_sz : *buflen);
     
     if (found) {
 	if (rreq->dev.recv_data_sz == 0) {
             /* return the number of bytes processed in this function */
-            *buflen = sizeof(MPIDI_CH3_Pkt_t) + data_len;;
+            *buflen = data_len;;
             mpi_errno = MPID_Request_complete(rreq);
-            if (mpi_errno != MPI_SUCCESS) {
-                MPIR_ERR_POP(mpi_errno);
-            }
+            MPIR_ERR_CHECK(mpi_errno);
 	    *rreqp = NULL;
 	}
 	else {
-	    mpi_errno = MPIDI_CH3U_Receive_data_found(rreq, data_buf, &data_len,
+	    mpi_errno = MPIDI_CH3U_Receive_data_found(rreq, data, &data_len,
                                                       &complete);
 	    if (mpi_errno != MPI_SUCCESS) {
 		MPIR_ERR_SETANDJUMP1(mpi_errno,MPI_ERR_OTHER, 
@@ -754,14 +717,12 @@ int MPIDI_CH3_PktHandler_ReadySend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt,
 	    }
 
             /* return the number of bytes processed in this function */
-            *buflen = sizeof(MPIDI_CH3_Pkt_t) + data_len;
+            *buflen = data_len;
 
             if (complete) 
             {
                 mpi_errno = MPID_Request_complete(rreq);
-                if (mpi_errno != MPI_SUCCESS) {
-                    MPIR_ERR_POP(mpi_errno);
-                }
+                MPIR_ERR_CHECK(mpi_errno);
                 *rreqp = NULL;
             }
             else
@@ -782,7 +743,7 @@ int MPIDI_CH3_PktHandler_ReadySend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt,
 	   mark the request with an error. */
 	
 	rreq->status.MPI_ERROR = MPIR_Err_create_code(MPI_SUCCESS, 
-				      MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, 
+				      MPIR_ERR_RECOVERABLE, __func__, __LINE__, 
 				      MPI_ERR_OTHER, "**rsendnomatch", 
 				      "**rsendnomatch %d %d", 
 				      ready_pkt->match.parts.rank,
@@ -792,8 +753,8 @@ int MPIDI_CH3_PktHandler_ReadySend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt,
 	{
 	    /* force read of extra data */
 	    *rreqp = rreq;
-	    rreq->dev.segment_first = 0;
-	    rreq->dev.segment_size = 0;
+	    rreq->dev.msg_offset = 0;
+	    rreq->dev.msgsize = 0;
 	    mpi_errno = MPIDI_CH3U_Request_load_recv_iov(rreq);
 	    if (mpi_errno != MPI_SUCCESS) {
 		MPIR_ERR_SETANDJUMP(mpi_errno,MPI_ERR_OTHER,
@@ -804,13 +765,11 @@ int MPIDI_CH3_PktHandler_ReadySend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt,
 	{
 	    /* mark data transfer as complete and decrement CC */
             mpi_errno = MPID_Request_complete(rreq);
-            if (mpi_errno != MPI_SUCCESS) {
-                MPIR_ERR_POP(mpi_errno);
-            }
+            MPIR_ERR_CHECK(mpi_errno);
 	    *rreqp = NULL;
 	}
         /* we didn't process anything but the header in this case */
-        *buflen = sizeof(MPIDI_CH3_Pkt_t);
+        *buflen = 0;
     }
  fn_fail:
     return mpi_errno;
@@ -824,14 +783,14 @@ int MPIDI_CH3_PktHandler_ReadySend( MPIDI_VC_t *vc, MPIDI_CH3_Pkt_t *pkt,
 #ifdef MPICH_DBG_OUTPUT
 int MPIDI_CH3_PktPrint_EagerSend( FILE *fp, MPIDI_CH3_Pkt_t *pkt )
 {
-    MPIU_DBG_PRINTF((" type ......... EAGER_SEND\n"));
-    MPIU_DBG_PRINTF((" sender_reqid . 0x%08X\n", pkt->eager_send.sender_req_id));
-    MPIU_DBG_PRINTF((" context_id ... %d\n", pkt->eager_send.match.parts.context_id));
-    MPIU_DBG_PRINTF((" tag .......... %d\n", pkt->eager_send.match.parts.tag));
-    MPIU_DBG_PRINTF((" rank ......... %d\n", pkt->eager_send.match.parts.rank));
-    MPIU_DBG_PRINTF((" data_sz ...... %d\n", pkt->eager_send.data_sz));
+    MPL_DBG_MSG(MPIDI_CH3_DBG_OTHER,TERSE," type ......... EAGER_SEND\n");
+    MPL_DBG_MSG_FMT(MPIDI_CH3_DBG_OTHER,TERSE,(MPL_DBG_FDEST," sender_reqid . 0x%08X\n", pkt->eager_send.sender_req_id));
+    MPL_DBG_MSG_D(MPIDI_CH3_DBG_OTHER,TERSE," context_id ... %d\n", pkt->eager_send.match.parts.context_id);
+    MPL_DBG_MSG_D(MPIDI_CH3_DBG_OTHER,TERSE," tag .......... %d\n", pkt->eager_send.match.parts.tag);
+    MPL_DBG_MSG_D(MPIDI_CH3_DBG_OTHER,TERSE," rank ......... %d\n", pkt->eager_send.match.parts.rank);
+    MPL_DBG_MSG_D(MPIDI_CH3_DBG_OTHER,TERSE," data_sz ...... %d\n", pkt->eager_send.data_sz);
 #ifdef MPID_USE_SEQUENCE_NUMBERS
-    MPIU_DBG_PRINTF((" seqnum ....... %d\n", pkt->eager_send.seqnum));
+    MPL_DBG_MSG_D(MPIDI_CH3_DBG_OTHER,TERSE," seqnum ....... %d\n", pkt->eager_send.seqnum);
 #endif
 }
 
@@ -840,13 +799,13 @@ int MPIDI_CH3_PktPrint_EagerShortSend( FILE *fp, MPIDI_CH3_Pkt_t *pkt )
 {
     int datalen;
     unsigned char *p = (unsigned char *)pkt->eagershort_send.data;
-    MPIU_DBG_PRINTF((" type ......... EAGERSHORT_SEND\n"));
-    MPIU_DBG_PRINTF((" context_id ... %d\n", pkt->eagershort_send.match.parts.context_id));
-    MPIU_DBG_PRINTF((" tag .......... %d\n", pkt->eagershort_send.match.parts.tag));
-    MPIU_DBG_PRINTF((" rank ......... %d\n", pkt->eagershort_send.match.parts.rank));
-    MPIU_DBG_PRINTF((" data_sz ...... %d\n", pkt->eagershort_send.data_sz));
+    MPL_DBG_MSG(MPIDI_CH3_DBG_OTHER,TERSE," type ......... EAGERSHORT_SEND\n");
+    MPL_DBG_MSG_D(MPIDI_CH3_DBG_OTHER,TERSE," context_id ... %d\n", pkt->eagershort_send.match.parts.context_id);
+    MPL_DBG_MSG_D(MPIDI_CH3_DBG_OTHER,TERSE," tag .......... %d\n", pkt->eagershort_send.match.parts.tag);
+    MPL_DBG_MSG_D(MPIDI_CH3_DBG_OTHER,TERSE," rank ......... %d\n", pkt->eagershort_send.match.parts.rank);
+    MPL_DBG_MSG_D(MPIDI_CH3_DBG_OTHER,TERSE," data_sz ...... %d\n", pkt->eagershort_send.data_sz);
 #ifdef MPID_USE_SEQUENCE_NUMBERS
-    MPIU_DBG_PRINTF((" seqnum ....... %d\n", pkt->eagershort_send.seqnum));
+    MPL_DBG_MSG_D(MPIDI_CH3_DBG_OTHER,TERSE," seqnum ....... %d\n", pkt->eagershort_send.seqnum);
 #endif
     datalen = pkt->eagershort_send.data_sz;
     if (datalen > 0) {
@@ -856,21 +815,21 @@ int MPIDI_CH3_PktPrint_EagerShortSend( FILE *fp, MPIDI_CH3_Pkt_t *pkt )
 	for (i=0; i<datalen; i++) {
 	    MPL_snprintf( &databytes[2*i], 64 - 2*i, "%2x", p[i] );
 	}
-	MPIU_DBG_PRINTF((" data ......... %s\n", databytes));
+	MPL_DBG_MSG_S(MPIDI_CH3_DBG_OTHER,TERSE," data ......... %s\n", databytes);
     }
 }
 #endif /* defined(USE_EAGER_SHORT) */
 
 int MPIDI_CH3_PktPrint_ReadySend( FILE *fp, MPIDI_CH3_Pkt_t *pkt )
 {
-    MPIU_DBG_PRINTF((" type ......... READY_SEND\n"));
-    MPIU_DBG_PRINTF((" sender_reqid . 0x%08X\n", pkt->ready_send.sender_req_id));
-    MPIU_DBG_PRINTF((" context_id ... %d\n", pkt->ready_send.match.parts.context_id));
-    MPIU_DBG_PRINTF((" tag .......... %d\n", pkt->ready_send.match.parts.tag));
-    MPIU_DBG_PRINTF((" rank ......... %d\n", pkt->ready_send.match.parts.rank));
-    MPIU_DBG_PRINTF((" data_sz ...... %d\n", pkt->ready_send.data_sz));
+    MPL_DBG_MSG(MPIDI_CH3_DBG_OTHER,TERSE," type ......... READY_SEND\n");
+    MPL_DBG_MSG_FMT(MPIDI_CH3_DBG_OTHER,TERSE,(MPL_DBG_FDEST," sender_reqid . 0x%08X\n", pkt->ready_send.sender_req_id));
+    MPL_DBG_MSG_D(MPIDI_CH3_DBG_OTHER,TERSE," context_id ... %d\n", pkt->ready_send.match.parts.context_id);
+    MPL_DBG_MSG_D(MPIDI_CH3_DBG_OTHER,TERSE," tag .......... %d\n", pkt->ready_send.match.parts.tag);
+    MPL_DBG_MSG_D(MPIDI_CH3_DBG_OTHER,TERSE," rank ......... %d\n", pkt->ready_send.match.parts.rank);
+    MPL_DBG_MSG_D(MPIDI_CH3_DBG_OTHER,TERSE," data_sz ...... %d\n", pkt->ready_send.data_sz);
 #ifdef MPID_USE_SEQUENCE_NUMBERS
-    MPIU_DBG_PRINTF((" seqnum ....... %d\n", pkt->ready_send.seqnum));
+    MPL_DBG_MSG_D(MPIDI_CH3_DBG_OTHER,TERSE," seqnum ....... %d\n", pkt->ready_send.seqnum);
 #endif
 }
 
