@@ -1,7 +1,6 @@
-/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
- *  (C) 2008 by Argonne National Laboratory.
- *      See COPYRIGHT in top-level directory.
+ * Copyright (C) by Argonne National Laboratory
+ *     See COPYRIGHT in top-level directory
  */
 
 #ifndef HYDRA_H_INCLUDED
@@ -15,6 +14,7 @@
 #include "hydra_config.h"
 
 #include "mpl.h"
+#include "uthash.h"
 
 extern char *HYD_dbg_prefix;
 
@@ -141,14 +141,14 @@ extern char *HYD_dbg_prefix;
         printf("\n");                                    \
     }
 
-#define HYD_CONVERT_FALSE_TO_NULL(x) \
+#define HYD_CONVERT_FALSE_TO_NULL(x)                                    \
     {                                                                   \
-        if (!(x)) {                                                     \
+        if ((x) == NULL) {                                              \
         }                                                               \
         else if (!strcasecmp((x), "none") || !strcasecmp((x), "no") ||  \
                  !strcasecmp((x), "dummy") || !strcasecmp((x), "null") || \
                  !strcasecmp((x), "nil") || !strcasecmp((x), "false")) { \
-            HYDU_FREE((x));                                             \
+            MPL_free((x));                                              \
             (x) = NULL;                                                 \
         }                                                               \
     }
@@ -158,7 +158,7 @@ extern char **environ;
 #endif /* MANUAL_EXTERN_ENVIRON */
 
 #if defined NEEDS_HSTRERROR_DECL
-const char * hstrerror(int err);
+const char *hstrerror(int err);
 #endif /* NEEDS_HSTRERROR_DECL */
 
 #if defined NEEDS_GETTIMEOFDAY_DECL
@@ -193,9 +193,9 @@ struct HYD_string_stash {
 #define HYD_STRING_STASH(stash, str, status)                            \
     do {                                                                \
         if ((stash).cur_count >= (stash).max_count - 1) {               \
-            HYDU_REALLOC((stash).strlist, char **,                      \
-                         ((stash).max_count + HYD_NUM_TMP_STRINGS) * sizeof(char *), \
-                         (status));                                     \
+            HYDU_REALLOC_OR_JUMP((stash).strlist, char **,              \
+                                 ((stash).max_count + HYD_NUM_TMP_STRINGS) * sizeof(char *), \
+                                 (status));                             \
             (stash).max_count += HYD_NUM_TMP_STRINGS;                   \
         }                                                               \
         (stash).strlist[(stash).cur_count++] = (str);                   \
@@ -205,13 +205,13 @@ struct HYD_string_stash {
 #define HYD_STRING_SPIT(stash, str, status)                             \
     do {                                                                \
         if ((stash).cur_count == 0) {                                   \
-            (str) = HYDU_strdup("");                                    \
+            (str) = MPL_strdup("");                                     \
         }                                                               \
         else {                                                          \
             (status) = HYDU_str_alloc_and_join((stash).strlist, &(str)); \
             HYDU_ERR_POP((status), "unable to join strings\n");         \
             HYDU_free_strlist((stash).strlist);                         \
-            HYDU_FREE((stash).strlist);                                 \
+            MPL_free((stash).strlist);                                  \
             HYD_STRING_STASH_INIT((stash));                             \
         }                                                               \
     } while (0)
@@ -221,7 +221,7 @@ struct HYD_string_stash {
         if ((stash).strlist == NULL)            \
             break;                              \
         HYDU_free_strlist((stash).strlist);     \
-        HYDU_FREE((stash).strlist);             \
+        MPL_free((stash).strlist);              \
         (stash).max_count = 0;                  \
         (stash).cur_count = 0;                  \
     } while (0)
@@ -257,6 +257,9 @@ typedef enum {
 #define HYD_USIZE_SYSTEM    (-1)
 #define HYD_USIZE_INFINITE  (-2)
 
+#define HYD_GPUS_PER_PROC_UNSET   (-1)
+#define HYD_GPUS_PER_PROC_AUTO    (-2)
+
 #if defined(NEEDS_GETHOSTNAME_DECL)
 int gethostname(char *name, size_t len);
 #endif
@@ -273,8 +276,8 @@ struct HYD_arg_match_table {
 
 /* Environment information */
 struct HYD_env {
-    const char *env_name;
-    const char *env_value;
+    char *env_name;
+    char *env_value;
     struct HYD_env *next;
 };
 
@@ -315,6 +318,7 @@ struct HYD_exec {
 struct HYD_pg {
     int pgid;
     struct HYD_proxy *proxy_list;
+    int proxy_count;
     int pg_process_count;
     int barrier_count;
 
@@ -369,6 +373,8 @@ struct HYD_proxy {
     int control_fd;
 
     struct HYD_proxy *next;
+
+    UT_hash_handle hh;
 };
 
 /* Global user parameters */
@@ -385,11 +391,7 @@ struct HYD_user_global {
     char *binding;
     char *mapping;
     char *membind;
-
-    /* Checkpoint restart */
-    char *ckpointlib;
-    char *ckpoint_prefix;
-    int ckpoint_num;
+    int topo_debug;
 
     /* Demux engine */
     char *demux;
@@ -403,13 +405,16 @@ struct HYD_user_global {
     int usize;
 
     int auto_cleanup;
+    int pmi_port;
+    int skip_launch_node;
+    int gpus_per_proc;
 
     struct HYD_env_global global_env;
 };
 
 #define HYDU_dump_prefix(fp)                    \
     {                                           \
-        fprintf(fp, "[%s] ", HYD_dbg_prefix);   \
+        fprintf(fp, "[%s] ", HYD_dbg_prefix ? HYD_dbg_prefix : "unknown");   \
         fflush(fp);                             \
     }
 
@@ -441,26 +446,26 @@ struct HYD_user_global {
         HYDU_dump_noprefix(stderr, __VA_ARGS__);                        \
     }
 #elif defined __FILE__
-#define HYDU_error_printf(...)                            \
-    {                                                     \
+#define HYDU_error_printf(...)                                          \
+    {                                                                   \
         HYDU_dump_prefix(stderr);                                       \
         HYDU_dump_noprefix(stderr, "%s (%d): ", __FILE__, __LINE__);    \
         HYDU_dump_noprefix(stderr, __VA_ARGS__);                        \
     }
 #else
-#define HYDU_error_printf(...)                                          \
-    {                                                                   \
-        HYDU_dump_prefix(stderr);                                       \
-        HYDU_dump_noprefix(stderr, __VA_ARGS__);                        \
+#define HYDU_error_printf(...)                          \
+    {                                                   \
+        HYDU_dump_prefix(stderr);                       \
+        HYDU_dump_noprefix(stderr, __VA_ARGS__);        \
     }
 #endif
 
-#define HYDU_ASSERT(x, status)                                          \
-    {                                                                   \
-        if (!(x)) {                                                     \
-            HYDU_ERR_SETANDJUMP(status, HYD_INTERNAL_ERROR,             \
-                                 "assert (%s) failed\n", #x);           \
-        }                                                               \
+#define HYDU_ASSERT(x, status)                                  \
+    {                                                           \
+        if ((x) == 0) {                                         \
+            HYDU_ERR_SETANDJUMP(status, HYD_INTERNAL_ERROR,     \
+                                "assert (%s) failed\n", #x);    \
+        }                                                       \
     }
 
 #define HYDU_IGNORE_TIMEOUT(status)             \
@@ -469,27 +474,27 @@ struct HYD_user_global {
             (status) = HYD_SUCCESS;             \
     }
 
-#define HYDU_ERR_POP(status, ...)                                       \
-    {                                                                   \
-        if (status && !HYD_SILENT_ERROR(status)) {                      \
-            HYDU_error_printf(__VA_ARGS__);                             \
-            goto fn_fail;                                               \
-        }                                                               \
-        else if (HYD_SILENT_ERROR(status)) {                            \
-            goto fn_exit;                                               \
-        }                                                               \
+#define HYDU_ERR_POP(status, ...)                       \
+    {                                                   \
+        if (status && !HYD_SILENT_ERROR(status)) {      \
+            HYDU_error_printf(__VA_ARGS__);             \
+            goto fn_fail;                               \
+        }                                               \
+        else if (HYD_SILENT_ERROR(status)) {            \
+            goto fn_exit;                               \
+        }                                               \
     }
 
-#define HYDU_ERR_SETANDJUMP(status, error, ...)                         \
-    {                                                                   \
-        status = error;                                                 \
-        HYDU_ERR_POP(status, __VA_ARGS__);                              \
+#define HYDU_ERR_SETANDJUMP(status, error, ...) \
+    {                                           \
+        status = error;                         \
+        HYDU_ERR_POP(status, __VA_ARGS__);      \
     }
 
-#define HYDU_ERR_CHKANDJUMP(status, chk, error, ...)                    \
-    {                                                                   \
-        if ((chk))                                                      \
-            HYDU_ERR_SETANDJUMP(status, error, __VA_ARGS__);            \
+#define HYDU_ERR_CHKANDJUMP(status, chk, error, ...)            \
+    {                                                           \
+        if ((chk))                                              \
+            HYDU_ERR_SETANDJUMP(status, error, __VA_ARGS__);    \
     }
 
 #if defined ENABLE_WARNINGS
@@ -597,9 +602,10 @@ HYD_status HYDU_sock_read(int fd, void *buf, int maxlen, int *recvd, int *closed
 HYD_status HYDU_sock_write(int fd, const void *buf, int maxlen, int *sent, int *closed,
                            enum HYDU_sock_comm_flag flag);
 HYD_status HYDU_sock_set_nonblock(int fd);
+HYD_status HYDU_sock_set_block(int fd);
 HYD_status HYDU_sock_forward_stdio(int in, int out, int *closed);
+void HYDU_sock_finalize(void);
 HYD_status HYDU_sock_get_iface_ip(char *iface, char **ip);
-HYD_status HYDU_sock_is_local(char *host, int *is_local);
 HYD_status
 HYDU_sock_create_and_listen_portstr(char *iface, char *hostname, char *port_range,
                                     char **port_str,
@@ -611,63 +617,24 @@ HYD_status HYDU_sock_cloexec(int fd);
 /* Memory utilities */
 #include <ctype.h>
 
-#if defined USE_MEMORY_TRACING
-
-#define HYDU_mem_init()  MPL_trinit(0)
-
-#define HYDU_strdup(a) MPL_trstrdup(a,__LINE__,__FILE__)
-#ifdef strdup
-#undef strdup
-#endif
-#define strdup(a)      'Error use HYDU_strdup' :::
-
-#define HYDU_malloc(a) MPL_trmalloc((unsigned)(a),__LINE__,__FILE__)
-#define malloc(a)      'Error use HYDU_malloc' :::
-
-#define HYDU_realloc(a,b) MPL_trrealloc((void *)(a),(unsigned)(b),__LINE__,__FILE__)
-#define realloc(a)      'Error use HYDU_realloc' :::
-
-#define HYDU_free(a) MPL_trfree(a,__LINE__,__FILE__)
-#define free(a)      'Error use HYDU_free' :::
-
-#else /* if !defined USE_MEMORY_TRACING */
-
-#define HYDU_mem_init()
-#define HYDU_strdup MPL_strdup
-#define HYDU_malloc malloc
-#define HYDU_realloc realloc
-#define HYDU_free free
-
-#endif /* USE_MEMORY_TRACING */
-
-#define HYDU_snprintf MPL_snprintf
-
-#define HYDU_MALLOC(p, type, size, status)                              \
+#define HYDU_MALLOC_OR_JUMP(p, type, size, status)                      \
     {                                                                   \
-        (p) = NULL; /* initialize p in case assert fails */             \
-        HYDU_ASSERT(size, status);                                      \
-        (p) = (type) HYDU_malloc((size));                               \
-        if ((p) == NULL)                                                \
+        (p) = (type) MPL_malloc((size), MPL_MEM_PM);                 \
+        if ((size != 0) && ((p) == NULL))                               \
             HYDU_ERR_SETANDJUMP((status), HYD_NO_MEM,                   \
                                 "failed to allocate %d bytes\n",        \
                                 (int) (size));                          \
     }
 
-#define HYDU_REALLOC(p, type, size, status)                             \
+#define HYDU_REALLOC_OR_JUMP(p, type, size, status)                     \
     {                                                                   \
-        HYDU_ASSERT(size, status);                                      \
-        (p) = (type) HYDU_realloc((p),(size));                          \
-        if ((p) == NULL)                                                \
+        (p) = (type) MPL_realloc((p),(size), MPL_MEM_PM);            \
+        if ((size != 0) && ((p) == NULL))                               \
             HYDU_ERR_SETANDJUMP((status), HYD_NO_MEM,                   \
                                 "failed to allocate %d bytes\n",        \
                                 (int) (size));                          \
     }
 
-#define HYDU_FREE(p)                            \
-    {                                           \
-        HYDU_free((void *) p);                  \
-    }
-
 HYD_status HYDU_list_append_strlist(char **exec, char **client_arg);
 HYD_status HYDU_print_strlist(char **args);
 void HYDU_free_strlist(char **args);
@@ -678,12 +645,6 @@ char *HYDU_size_t_to_str(size_t x);
 char *HYDU_int_to_str(int x);
 char *HYDU_int_to_str_pad(int x, int maxlen);
 
-#if defined HAVE_STRERROR
-#define HYDU_strerror strerror
-#else
-#define HYDU_strerror HYDU_int_to_str
-#endif /* HAVE_STRERROR */
-
 #if defined HAVE_HERROR
 #define HYDU_herror herror
 #else
