@@ -1,23 +1,23 @@
-/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
- *  (C) 2001 by Argonne National Laboratory.
- *      See COPYRIGHT in top-level directory.
+ * Copyright (C) by Argonne National Laboratory
+ *     See COPYRIGHT in top-level directory
  */
 
 #include "mpi.h"
 #include <stdio.h>
+#include "mpitest.h"
 
 static int verbose = 0;
 
 int main(int argc, char *argv[])
 {
     char value[MPI_MAX_INFO_VAL];
-    char *keys[] = { "command", "argv", "maxprocs", "soft", "host", "arch", "wdir", "file",
+    const char *keys[] = { "command", "argv", "maxprocs", "soft", "host", "arch", "wdir", "file",
         "thread_level", 0
     };
     int flag, i;
 
-    MPI_Init(NULL, NULL);
+    MTest_Init(&argc, &argv);
 
     for (i = 0; keys[i]; i++) {
         MPI_Info_get(MPI_INFO_ENV, keys[i], MPI_MAX_INFO_VAL, value, &flag);
@@ -25,8 +25,6 @@ int main(int argc, char *argv[])
             printf("command: %s\n", value);
     }
 
-    printf(" No Errors\n");
-
-    MPI_Finalize();
+    MTest_Finalize(0);
     return 0;
 }
