@@ -1,7 +1,6 @@
-/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil ; -*- */
 /*
- *  (C) 2013 by Argonne National Laboratory.
- *      See COPYRIGHT in top-level directory.
+ * Copyright (C) by Argonne National Laboratory
+ *     See COPYRIGHT in top-level directory
  */
 
 /* This test is adapted from test/mpi/mpi_t/mpit_vars.c.
@@ -28,11 +27,12 @@ const int NTHREADS = 8;
 static int verbose = 0;
 #define DOPRINT (verbose && myThreadId == 0)
 
-char *mpit_scopeToStr(int scope);
-char *mpit_bindingToStr(int binding);
-char *mpit_validDtypeStr(MPI_Datatype datatype);
-char *mpit_varclassToStr(int varClass);
-char *mpit_verbosityToStr(int verbosity);
+const char *mpit_scopeToStr(int scope);
+const char *mpit_bindingToStr(int binding);
+const char *mpit_validDtypeStr(MPI_Datatype datatype);
+const char *mpit_varclassToStr(int varClass);
+const char *mpit_verbosityToStr(int verbosity);
+const char *mpit_errclassToStr(int err);
 int perfvarReadInt(int pvarIndex, int isContinuous, int *found);
 unsigned int perfvarReadUint(int pvarIndex, int isContinuous, int *found);
 double perfvarReadDouble(int pvarIndex, int isContinuous, int *found);
@@ -68,7 +68,7 @@ int main(int argc, char *argv[])
         MPI_Abort(MPI_COMM_WORLD, -1);
     }
 
-    MPI_Init_thread(&argc, &argv, required, &provided);
+    MTest_Init_thread(&argc, &argv, required, &provided);
     if (provided != MPI_THREAD_MULTIPLE) {
         fprintf(stderr, "MPI_THREAD_MULTIPLE not supported by the MPI implementation\n");
         MPI_Abort(MPI_COMM_WORLD, -1);
@@ -89,9 +89,7 @@ int main(int argc, char *argv[])
      * are freed in MPI_T_finalize().
      */
     MPI_T_finalize();
-    MPI_Finalize();
-
-    fprintf(stdout, " No Errors\n");
+    MTest_Finalize(0);
 
     return 0;
 }
@@ -138,8 +136,7 @@ int PrintControlVars(FILE * fp, int myThreadId)
                     mpit_scopeToStr(scope),
                     mpit_bindingToStr(binding),
                     mpit_validDtypeStr(datatype), mpit_verbosityToStr(verbosity), desc);
-        }
-        else if (DOPRINT) {
+        } else if (DOPRINT) {
             fprintf(fp, "\t%s\t%s\t%s\t%s\t%s\t%s\n",
                     name,
                     mpit_scopeToStr(scope),
@@ -184,15 +181,13 @@ int PrintPerfVars(FILE * fp, int myThreadId)
             val = perfvarReadInt(i, isContinuous, &isFound);
             if (isFound && DOPRINT)
                 fprintf(fp, "\tValue = %d\n", val);
-        }
-        else if (datatype == MPI_UNSIGNED) {
+        } else if (datatype == MPI_UNSIGNED) {
             int isFound;
             unsigned int val;
             val = perfvarReadUint(i, isContinuous, &isFound);
             if (isFound && DOPRINT)
                 fprintf(fp, "\tValue = %u\n", val);
-        }
-        else if (datatype == MPI_DOUBLE) {
+        } else if (datatype == MPI_DOUBLE) {
             int isFound;
             double val;
             val = perfvarReadDouble(i, isContinuous, &isFound);
@@ -264,7 +259,6 @@ int PrintCategories(FILE * fp, int myThreadId)
                                     &isReadonly, &isContinuous, &isAtomic);
                 if (DOPRINT)
                     fprintf(fp, "%s, ", varname);
-
             }
             free(pvarIndex);
             if (DOPRINT)
@@ -285,7 +279,6 @@ int PrintCategories(FILE * fp, int myThreadId)
                                         &ncvars, &npvars, &nsubcats);
                 if (DOPRINT)
                     fprintf(fp, "%s, ", catname);
-
             }
             free(subcatIndex);
             if (DOPRINT)
@@ -299,9 +292,9 @@ int PrintCategories(FILE * fp, int myThreadId)
 
 /* --- Support routines --- */
 
-char *mpit_validDtypeStr(MPI_Datatype datatype)
+const char *mpit_validDtypeStr(MPI_Datatype datatype)
 {
-    char *p = 0;
+    const char *p = 0;
     if (datatype == MPI_INT)
         p = "MPI_INT";
     else if (datatype == MPI_UNSIGNED)
@@ -319,8 +312,7 @@ char *mpit_validDtypeStr(MPI_Datatype datatype)
     else {
         if (datatype == MPI_DATATYPE_NULL) {
             p = "Invalid MPI datatype:NULL";
-        }
-        else {
+        } else {
             static char typename[MPI_MAX_OBJECT_NAME + 9];
             int tlen;
             strncpy(typename, "Invalid:", MPI_MAX_OBJECT_NAME);
@@ -333,209 +325,209 @@ char *mpit_validDtypeStr(MPI_Datatype datatype)
     return p;
 }
 
-char *mpit_scopeToStr(int scope)
+const char *mpit_scopeToStr(int scope)
 {
-    char *p = 0;
+    const char *p = 0;
     switch (scope) {
-    case MPI_T_SCOPE_CONSTANT:
-        p = "SCOPE_CONSTANT";
-        break;
-    case MPI_T_SCOPE_READONLY:
-        p = "SCOPE_READONLY";
-        break;
-    case MPI_T_SCOPE_LOCAL:
-        p = "SCOPE_LOCAL";
-        break;
-    case MPI_T_SCOPE_GROUP:
-        p = "SCOPE_GROUP";
-        break;
-    case MPI_T_SCOPE_GROUP_EQ:
-        p = "SCOPE_GROUP_EQ";
-        break;
-    case MPI_T_SCOPE_ALL:
-        p = "SCOPE_ALL";
-        break;
-    case MPI_T_SCOPE_ALL_EQ:
-        p = "SCOPE_ALL_EQ";
-        break;
-    default:
-        p = "Unrecoginized scope";
-        break;
+        case MPI_T_SCOPE_CONSTANT:
+            p = "SCOPE_CONSTANT";
+            break;
+        case MPI_T_SCOPE_READONLY:
+            p = "SCOPE_READONLY";
+            break;
+        case MPI_T_SCOPE_LOCAL:
+            p = "SCOPE_LOCAL";
+            break;
+        case MPI_T_SCOPE_GROUP:
+            p = "SCOPE_GROUP";
+            break;
+        case MPI_T_SCOPE_GROUP_EQ:
+            p = "SCOPE_GROUP_EQ";
+            break;
+        case MPI_T_SCOPE_ALL:
+            p = "SCOPE_ALL";
+            break;
+        case MPI_T_SCOPE_ALL_EQ:
+            p = "SCOPE_ALL_EQ";
+            break;
+        default:
+            p = "Unrecoginized scope";
+            break;
     }
     return p;
 }
 
-char *mpit_bindingToStr(int binding)
+const char *mpit_bindingToStr(int binding)
 {
-    char *p;
+    const char *p;
     switch (binding) {
-    case MPI_T_BIND_NO_OBJECT:
-        p = "NO_OBJECT";
-        break;
-    case MPI_T_BIND_MPI_COMM:
-        p = "MPI_COMM";
-        break;
-    case MPI_T_BIND_MPI_DATATYPE:
-        p = "MPI_DATATYPE";
-        break;
-    case MPI_T_BIND_MPI_ERRHANDLER:
-        p = "MPI_ERRHANDLER";
-        break;
-    case MPI_T_BIND_MPI_FILE:
-        p = "MPI_FILE";
-        break;
-    case MPI_T_BIND_MPI_GROUP:
-        p = "MPI_GROUP";
-        break;
-    case MPI_T_BIND_MPI_OP:
-        p = "MPI_OP";
-        break;
-    case MPI_T_BIND_MPI_REQUEST:
-        p = "MPI_REQUEST";
-        break;
-    case MPI_T_BIND_MPI_WIN:
-        p = "MPI_WIN";
-        break;
-    case MPI_T_BIND_MPI_MESSAGE:
-        p = "MPI_MESSAGE";
-        break;
-    case MPI_T_BIND_MPI_INFO:
-        p = "MPI_INFO";
-        break;
-    default:
-        p = "Unknown object binding";
+        case MPI_T_BIND_NO_OBJECT:
+            p = "NO_OBJECT";
+            break;
+        case MPI_T_BIND_MPI_COMM:
+            p = "MPI_COMM";
+            break;
+        case MPI_T_BIND_MPI_DATATYPE:
+            p = "MPI_DATATYPE";
+            break;
+        case MPI_T_BIND_MPI_ERRHANDLER:
+            p = "MPI_ERRHANDLER";
+            break;
+        case MPI_T_BIND_MPI_FILE:
+            p = "MPI_FILE";
+            break;
+        case MPI_T_BIND_MPI_GROUP:
+            p = "MPI_GROUP";
+            break;
+        case MPI_T_BIND_MPI_OP:
+            p = "MPI_OP";
+            break;
+        case MPI_T_BIND_MPI_REQUEST:
+            p = "MPI_REQUEST";
+            break;
+        case MPI_T_BIND_MPI_WIN:
+            p = "MPI_WIN";
+            break;
+        case MPI_T_BIND_MPI_MESSAGE:
+            p = "MPI_MESSAGE";
+            break;
+        case MPI_T_BIND_MPI_INFO:
+            p = "MPI_INFO";
+            break;
+        default:
+            p = "Unknown object binding";
     }
     return p;
 }
 
-char *mpit_varclassToStr(int varClass)
+const char *mpit_varclassToStr(int varClass)
 {
-    char *p = 0;
+    const char *p = 0;
     switch (varClass) {
-    case MPI_T_PVAR_CLASS_STATE:
-        p = "CLASS_STATE";
-        break;
-    case MPI_T_PVAR_CLASS_LEVEL:
-        p = "CLASS_LEVEL";
-        break;
-    case MPI_T_PVAR_CLASS_SIZE:
-        p = "CLASS_SIZE";
-        break;
-    case MPI_T_PVAR_CLASS_PERCENTAGE:
-        p = "CLASS_PERCENTAGE";
-        break;
-    case MPI_T_PVAR_CLASS_HIGHWATERMARK:
-        p = "CLASS_HIGHWATERMARK";
-        break;
-    case MPI_T_PVAR_CLASS_LOWWATERMARK:
-        p = "CLASS_LOWWATERMARK";
-        break;
-    case MPI_T_PVAR_CLASS_COUNTER:
-        p = "CLASS_COUNTER";
-        break;
-    case MPI_T_PVAR_CLASS_AGGREGATE:
-        p = "CLASS_AGGREGATE";
-        break;
-    case MPI_T_PVAR_CLASS_TIMER:
-        p = "CLASS_TIMER";
-        break;
-    case MPI_T_PVAR_CLASS_GENERIC:
-        p = "CLASS_GENERIC";
-        break;
-    default:
-        p = "Unrecognized pvar class";
-        break;
+        case MPI_T_PVAR_CLASS_STATE:
+            p = "CLASS_STATE";
+            break;
+        case MPI_T_PVAR_CLASS_LEVEL:
+            p = "CLASS_LEVEL";
+            break;
+        case MPI_T_PVAR_CLASS_SIZE:
+            p = "CLASS_SIZE";
+            break;
+        case MPI_T_PVAR_CLASS_PERCENTAGE:
+            p = "CLASS_PERCENTAGE";
+            break;
+        case MPI_T_PVAR_CLASS_HIGHWATERMARK:
+            p = "CLASS_HIGHWATERMARK";
+            break;
+        case MPI_T_PVAR_CLASS_LOWWATERMARK:
+            p = "CLASS_LOWWATERMARK";
+            break;
+        case MPI_T_PVAR_CLASS_COUNTER:
+            p = "CLASS_COUNTER";
+            break;
+        case MPI_T_PVAR_CLASS_AGGREGATE:
+            p = "CLASS_AGGREGATE";
+            break;
+        case MPI_T_PVAR_CLASS_TIMER:
+            p = "CLASS_TIMER";
+            break;
+        case MPI_T_PVAR_CLASS_GENERIC:
+            p = "CLASS_GENERIC";
+            break;
+        default:
+            p = "Unrecognized pvar class";
+            break;
     }
     return p;
 }
 
-char *mpit_verbosityToStr(int verbosity)
+const char *mpit_verbosityToStr(int verbosity)
 {
-    char *p = 0;
+    const char *p = 0;
     switch (verbosity) {
-    case MPI_T_VERBOSITY_USER_BASIC:
-        p = "VERBOSITY_USER_BASIC";
-        break;
-    case MPI_T_VERBOSITY_USER_DETAIL:
-        p = "VERBOSITY_USER_DETAIL";
-        break;
-    case MPI_T_VERBOSITY_USER_ALL:
-        p = "VERBOSITY_USER_ALL";
-        break;
-    case MPI_T_VERBOSITY_TUNER_BASIC:
-        p = "VERBOSITY_TUNER_BASIC";
-        break;
-    case MPI_T_VERBOSITY_TUNER_DETAIL:
-        p = "VERBOSITY_TUNER_DETAIL";
-        break;
-    case MPI_T_VERBOSITY_TUNER_ALL:
-        p = "VERBOSITY_TUNER_ALL";
-        break;
-    case MPI_T_VERBOSITY_MPIDEV_BASIC:
-        p = "VERBOSITY_MPIDEV_BASIC";
-        break;
-    case MPI_T_VERBOSITY_MPIDEV_DETAIL:
-        p = "VERBOSITY_MPIDEV_DETAIL";
-        break;
-    case MPI_T_VERBOSITY_MPIDEV_ALL:
-        p = "VERBOSITY_MPIDEV_ALL";
-        break;
-    default:
-        p = "Invalid verbosity";
-        break;
+        case MPI_T_VERBOSITY_USER_BASIC:
+            p = "VERBOSITY_USER_BASIC";
+            break;
+        case MPI_T_VERBOSITY_USER_DETAIL:
+            p = "VERBOSITY_USER_DETAIL";
+            break;
+        case MPI_T_VERBOSITY_USER_ALL:
+            p = "VERBOSITY_USER_ALL";
+            break;
+        case MPI_T_VERBOSITY_TUNER_BASIC:
+            p = "VERBOSITY_TUNER_BASIC";
+            break;
+        case MPI_T_VERBOSITY_TUNER_DETAIL:
+            p = "VERBOSITY_TUNER_DETAIL";
+            break;
+        case MPI_T_VERBOSITY_TUNER_ALL:
+            p = "VERBOSITY_TUNER_ALL";
+            break;
+        case MPI_T_VERBOSITY_MPIDEV_BASIC:
+            p = "VERBOSITY_MPIDEV_BASIC";
+            break;
+        case MPI_T_VERBOSITY_MPIDEV_DETAIL:
+            p = "VERBOSITY_MPIDEV_DETAIL";
+            break;
+        case MPI_T_VERBOSITY_MPIDEV_ALL:
+            p = "VERBOSITY_MPIDEV_ALL";
+            break;
+        default:
+            p = "Invalid verbosity";
+            break;
     }
     return p;
 }
 
-char *mpit_errclassToStr(int err)
+const char *mpit_errclassToStr(int err)
 {
-    char *p = 0;
+    const char *p = 0;
     switch (err) {
-    case MPI_T_ERR_MEMORY:
-        p = "ERR_MEMORY";
-        break;
-    case MPI_T_ERR_NOT_INITIALIZED:
-        p = "ERR_NOT_INITIALIZED";
-        break;
-    case MPI_T_ERR_CANNOT_INIT:
-        p = "ERR_CANNOT_INIT";
-        break;
-    case MPI_T_ERR_INVALID_INDEX:
-        p = "ERR_INVALID_INDEX";
-        break;
-    case MPI_T_ERR_INVALID_ITEM:
-        p = "ERR_INVALID_ITEM";
-        break;
-    case MPI_T_ERR_INVALID_HANDLE:
-        p = "ERR_INVALID_HANDLE";
-        break;
-    case MPI_T_ERR_OUT_OF_HANDLES:
-        p = "ERR_OUT_OF_HANDLES";
-        break;
-    case MPI_T_ERR_OUT_OF_SESSIONS:
-        p = "ERR_OUT_OF_SESSIONS";
-        break;
-    case MPI_T_ERR_INVALID_SESSION:
-        p = "ERR_INVALID_SESSION";
-        break;
-    case MPI_T_ERR_CVAR_SET_NOT_NOW:
-        p = "ERR_CVAR_SET_NOT_NOW";
-        break;
-    case MPI_T_ERR_CVAR_SET_NEVER:
-        p = "ERR_CVAR_SET_NEVER";
-        break;
-    case MPI_T_ERR_PVAR_NO_STARTSTOP:
-        p = "ERR_PVAR_NO_STARTSTOP";
-        break;
-    case MPI_T_ERR_PVAR_NO_WRITE:
-        p = "ERR_PVAR_NO_WRITE";
-        break;
-    case MPI_T_ERR_PVAR_NO_ATOMIC:
-        p = "ERR_PVAR_NO_ATOMIC";
-        break;
-    default:
-        p = "Unknown MPI_T_ERR class";
-        break;
+        case MPI_T_ERR_MEMORY:
+            p = "ERR_MEMORY";
+            break;
+        case MPI_T_ERR_NOT_INITIALIZED:
+            p = "ERR_NOT_INITIALIZED";
+            break;
+        case MPI_T_ERR_CANNOT_INIT:
+            p = "ERR_CANNOT_INIT";
+            break;
+        case MPI_T_ERR_INVALID_INDEX:
+            p = "ERR_INVALID_INDEX";
+            break;
+        case MPI_T_ERR_INVALID_ITEM:
+            p = "ERR_INVALID_ITEM";
+            break;
+        case MPI_T_ERR_INVALID_HANDLE:
+            p = "ERR_INVALID_HANDLE";
+            break;
+        case MPI_T_ERR_OUT_OF_HANDLES:
+            p = "ERR_OUT_OF_HANDLES";
+            break;
+        case MPI_T_ERR_OUT_OF_SESSIONS:
+            p = "ERR_OUT_OF_SESSIONS";
+            break;
+        case MPI_T_ERR_INVALID_SESSION:
+            p = "ERR_INVALID_SESSION";
+            break;
+        case MPI_T_ERR_CVAR_SET_NOT_NOW:
+            p = "ERR_CVAR_SET_NOT_NOW";
+            break;
+        case MPI_T_ERR_CVAR_SET_NEVER:
+            p = "ERR_CVAR_SET_NEVER";
+            break;
+        case MPI_T_ERR_PVAR_NO_STARTSTOP:
+            p = "ERR_PVAR_NO_STARTSTOP";
+            break;
+        case MPI_T_ERR_PVAR_NO_WRITE:
+            p = "ERR_PVAR_NO_WRITE";
+            break;
+        case MPI_T_ERR_PVAR_NO_ATOMIC:
+            p = "ERR_PVAR_NO_ATOMIC";
+            break;
+        default:
+            p = "Unknown MPI_T_ERR class";
+            break;
     }
     return p;
 }
